window.Gleam.initSearch([{"doc":"redraw_dom","title":"redraw_dom","content":"# Redraw DOM\n\nRedraw DOM is the renderer for Redraw, for browser. Take a look at\n[Redraw](https://hexdocs.pm/redraw) to get the whole package.\n","url":"index.html"},{"doc":"redraw/dom","title":"create_portal","content":"pub fn create_portal(\n  children: Component,\n  root: String,\n) -&gt; Result(Component, Nil)\n Let you render some children into a different part of the DOM.\n Contrarily to JavaScript, `create_portal` returns a `Result` to avoid runtime\n error. Indeed, when the provided root does not exist in your HTML, `create_portal`\n fails. You should never assume `create_portal` will work out-of-the-box when\n you&#39;re building a library. Otherwise, you could assert the resulting\n value in your application.\n\n \n import redraw\n import redraw/dom/client\n import redraw/dom/html\n\n pub fn main() {\n   let assert Ok(root) = client.create_root(&quot;app&quot;)\n   client.render(app)\n }\n\n fn app() {\n   let modal = modal()\n   use &lt;- redraw.component__(&quot;App&quot;)\n   let assert Ok(modal) = client.create_portal(modal, &quot;modal&quot;)\n   html.div([], [html.text(&quot;Hello World!&quot;), modal])\n }\n\n fn modal() {\n   use &lt;- redraw.component__(&quot;Modal&quot;)\n   html.div([], [html.text(&quot;Inside the modal!&quot;)])\n }\n \n\n [Documentation](https://react.dev/reference/react-dom/createPortal)\nSynonyms:\nredraw/dom.create_portal\nredraw/dom create_portal","url":"redraw/dom.html#create_portal"},{"doc":"redraw/dom","title":"flush_sync","content":"pub fn flush_sync(callback: fn() -&gt; Nil) -&gt; Nil\n Call `flushSync` to force React to flush any pending work and update the DOM\n synchronously. \\\n\n \n import redraw\n import redraw/dom\n import redraw/dom/events\n\n type Action {\n   Increment\n   Decrement\n }\n\n fn counter() {\n   use &lt;- redraw.component__()\n   let #(state, set_state) = redraw.set_state(0)\n   let on_click = fn(type_: Action) {\n     events.on_click(fn (event) {\n       // Calling flush_sync forces the DOM to refresh.\n       dom.flush_sync(fn () {\n         set_state(case type_ {\n           Increment -&gt; state + 1\n           Decrement -&gt; state - 1\n         })\n       })\n     })\n   }\n   html.div([], [\n     html.div([], [html.text(&quot;-&quot;)]),\n     html.div([], [html.text(int.to_string(state))]),\n     html.div([], [html.text(&quot;+&quot;)]),\n   ])\n }\n \n\n Most of the time, flushSync can be avoided. Use flushSync as last resort.\n\n [Documentation](https://react.dev/reference/react-dom/flushSync)\nSynonyms:\nredraw/dom.flush_sync\nredraw/dom flush_sync","url":"redraw/dom.html#flush_sync"},{"doc":"redraw/dom","title":"redraw/dom","content":"","url":"redraw/dom.html"},{"doc":"redraw/dom/attribute","title":"Attribute","content":"pub opaque type Attribute\n Attribute linked on an HTML or SVG node. Think about like a `prop` in React.\n\nSynonyms:\nredraw/dom/attribute.Attribute\nredraw/dom/attribute Attribute","url":"redraw/dom/attribute.html#Attribute"},{"doc":"redraw/dom/attribute","title":"Dir","content":"pub type Dir {\n  Ltr\n  Rtl\n}\n Directionality of an element text.\nLtr\n\n\nRtl\n\n\nSynonyms:\nredraw/dom/attribute.Dir\nredraw/dom/attribute Dir","url":"redraw/dom/attribute.html#Dir"},{"doc":"redraw/dom/attribute","title":"InnerHTML","content":"pub type InnerHTML\n Inner HTML data are HTML that will not be verified sanitized.\n Be careful when using it. You should almost always prefer to use\n `redraw/element/html`.\n\nSynonyms:\nredraw/dom/attribute.InnerHTML\nredraw/dom/attribute InnerHTML","url":"redraw/dom/attribute.html#InnerHTML"},{"doc":"redraw/dom/attribute","title":"Translate","content":"pub type Translate {\n  Yes\n  No\n}\n Translate of a translatable element.\nYes\n\n\nNo\n\n\nSynonyms:\nredraw/dom/attribute.Translate\nredraw/dom/attribute Translate","url":"redraw/dom/attribute.html#Translate"},{"doc":"redraw/dom/attribute","title":"accept","content":"pub fn accept(types: List(String)) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Attributes/accept)\nSynonyms:\nredraw/dom/attribute.accept\nredraw/dom/attribute accept","url":"redraw/dom/attribute.html#accept"},{"doc":"redraw/dom/attribute","title":"accept_charset","content":"pub fn accept_charset(types: List(String)) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/HTMLFormElement/acceptCharset)\nSynonyms:\nredraw/dom/attribute.accept_charset\nredraw/dom/attribute accept_charset","url":"redraw/dom/attribute.html#accept_charset"},{"doc":"redraw/dom/attribute","title":"access_key","content":"pub fn access_key(value: String) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Global_attributes/accesskey)\nSynonyms:\nredraw/dom/attribute.access_key\nredraw/dom/attribute access_key","url":"redraw/dom/attribute.html#access_key"},{"doc":"redraw/dom/attribute","title":"action","content":"pub fn action(url: String) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/HTMLFormElement/action)\nSynonyms:\nredraw/dom/attribute.action\nredraw/dom/attribute action","url":"redraw/dom/attribute.html#action"},{"doc":"redraw/dom/attribute","title":"alt","content":"pub fn alt(value: String) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/HTMLMediaElement/alt)\nSynonyms:\nredraw/dom/attribute.alt\nredraw/dom/attribute alt","url":"redraw/dom/attribute.html#alt"},{"doc":"redraw/dom/attribute","title":"aria","content":"pub fn aria(key: String, value: String) -&gt; Attribute\n Set aria attribute on the node. Should be used like `aria(&quot;valuenow&quot;, &quot;75&quot;)`.\nSynonyms:\nredraw/dom/attribute.aria\nredraw/dom/attribute aria","url":"redraw/dom/attribute.html#aria"},{"doc":"redraw/dom/attribute","title":"attribute","content":"pub fn attribute(key: String, content: a) -&gt; Attribute\n\nSynonyms:\nredraw/dom/attribute.attribute\nredraw/dom/attribute attribute","url":"redraw/dom/attribute.html#attribute"},{"doc":"redraw/dom/attribute","title":"auto_capitalize","content":"pub fn auto_capitalize(value: String) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Global_attributes/autocapitalize)\nSynonyms:\nredraw/dom/attribute.auto_capitalize\nredraw/dom/attribute auto_capitalize","url":"redraw/dom/attribute.html#auto_capitalize"},{"doc":"redraw/dom/attribute","title":"autocomplete","content":"pub fn autocomplete(name: String) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Attributes/autocomplete)\nSynonyms:\nredraw/dom/attribute.autocomplete\nredraw/dom/attribute autocomplete","url":"redraw/dom/attribute.html#autocomplete"},{"doc":"redraw/dom/attribute","title":"autofocus","content":"pub fn autofocus(should_autofocus: Bool) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Global_attributes/autofocus)\nSynonyms:\nredraw/dom/attribute.autofocus\nredraw/dom/attribute autofocus","url":"redraw/dom/attribute.html#autofocus"},{"doc":"redraw/dom/attribute","title":"autoplay","content":"pub fn autoplay(should_autoplay: Bool) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/HTMLMediaElement/autoplay)\nSynonyms:\nredraw/dom/attribute.autoplay\nredraw/dom/attribute autoplay","url":"redraw/dom/attribute.html#autoplay"},{"doc":"redraw/dom/attribute","title":"checked","content":"pub fn checked(is_checked: Bool) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/input#checked)\nSynonyms:\nredraw/dom/attribute.checked\nredraw/dom/attribute checked","url":"redraw/dom/attribute.html#checked"},{"doc":"redraw/dom/attribute","title":"class","content":"pub fn class(value: String) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Global_attributes/class)\nSynonyms:\nredraw/dom/attribute.class\nredraw/dom/attribute class","url":"redraw/dom/attribute.html#class"},{"doc":"redraw/dom/attribute","title":"class_name","content":"pub fn class_name(value: String) -&gt; Attribute\n Alias of `class`. \\\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Global_attributes/class)\nSynonyms:\nredraw/dom/attribute.class_name\nredraw/dom/attribute class_name","url":"redraw/dom/attribute.html#class_name"},{"doc":"redraw/dom/attribute","title":"cols","content":"pub fn cols(val: Int) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/HTMLTextAreaElement/cols)\nSynonyms:\nredraw/dom/attribute.cols\nredraw/dom/attribute cols","url":"redraw/dom/attribute.html#cols"},{"doc":"redraw/dom/attribute","title":"content_editable","content":"pub fn content_editable(value: Bool) -&gt; Attribute\n If true, the browser lets the user edit the rendered element directly.\n This is used to implement rich text input libraries like Lexical. React\n warns if you try to pass React children to an element with\n `content_editable(True)` because React will not be able to update its content\n after user edits. \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/HTML/Global_attributes/contenteditable)\nSynonyms:\nredraw/dom/attribute.content_editable\nredraw/dom/attribute content_editable","url":"redraw/dom/attribute.html#content_editable"},{"doc":"redraw/dom/attribute","title":"controls","content":"pub fn controls(visible: Bool) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/HTMLMediaElement/controls)\nSynonyms:\nredraw/dom/attribute.controls\nredraw/dom/attribute controls","url":"redraw/dom/attribute.html#controls"},{"doc":"redraw/dom/attribute","title":"dangerously_set_inner_html","content":"pub fn dangerously_set_inner_html(\n  inner_html: InnerHTML,\n) -&gt; Attribute\n Overrides the innerHTML property of the DOM node and displays the passed\n HTML inside. This should be used with extreme caution! If the HTML inside\n isn’t trusted (for example, if it’s based on user data), you risk\n introducing an XSS vulnerability. \\\n [Documentation](https://react.dev/reference/react-dom/components/common#dangerously-setting-the-inner-html)\nSynonyms:\nredraw/dom/attribute.dangerously_set_inner_html\nredraw/dom/attribute dangerously_set_inner_html","url":"redraw/dom/attribute.html#dangerously_set_inner_html"},{"doc":"redraw/dom/attribute","title":"data","content":"pub fn data(key: String, value: String) -&gt; Attribute\n Data attributes let you attach some string data to the element, for example\n `data(&quot;fruit&quot;, &quot;banana&quot;)`. In React, they are not commonly used because you\n would usually read data from props or state instead. \\\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Global_attributes/data-*)\nSynonyms:\nredraw/dom/attribute.data\nredraw/dom/attribute data","url":"redraw/dom/attribute.html#data"},{"doc":"redraw/dom/attribute","title":"dir","content":"pub fn dir(value: Dir) -&gt; Attribute\n Specifies the text direction of the element. \\\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Global_attributes/dir)\nSynonyms:\nredraw/dom/attribute.dir\nredraw/dom/attribute dir","url":"redraw/dom/attribute.html#dir"},{"doc":"redraw/dom/attribute","title":"disabled","content":"pub fn disabled(is_disabled: Bool) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Attributes/disabled)\nSynonyms:\nredraw/dom/attribute.disabled\nredraw/dom/attribute disabled","url":"redraw/dom/attribute.html#disabled"},{"doc":"redraw/dom/attribute","title":"download","content":"pub fn download(filename: String) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/HTMLAnchorElement/download)\nSynonyms:\nredraw/dom/attribute.download\nredraw/dom/attribute download","url":"redraw/dom/attribute.html#download"},{"doc":"redraw/dom/attribute","title":"draggable","content":"pub fn draggable(value: Bool) -&gt; Attribute\n Specifies whether the element is draggable. Part of HTML Drag and Drop API. \\\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Global_attributes/draggable)\nSynonyms:\nredraw/dom/attribute.draggable\nredraw/dom/attribute draggable","url":"redraw/dom/attribute.html#draggable"},{"doc":"redraw/dom/attribute","title":"enctype","content":"pub fn enctype(value: String) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/HTMLFormElement/enctype)\nSynonyms:\nredraw/dom/attribute.enctype\nredraw/dom/attribute enctype","url":"redraw/dom/attribute.html#enctype"},{"doc":"redraw/dom/attribute","title":"enter_key_hint","content":"pub fn enter_key_hint(value: String) -&gt; Attribute\n Specifies which action to present for the enter key on virtual keyboards.\\\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Global_attributes/enterkeyhint)\nSynonyms:\nredraw/dom/attribute.enter_key_hint\nredraw/dom/attribute enter_key_hint","url":"redraw/dom/attribute.html#enter_key_hint"},{"doc":"redraw/dom/attribute","title":"for","content":"pub fn for(value: String) -&gt; Attribute\n For &lt;label&gt; and &lt;output&gt;, lets you associate the label with some control.\n Same as for HTML attribute. \\\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Attributes/for)\nSynonyms:\nredraw/dom/attribute.for\nredraw/dom/attribute for","url":"redraw/dom/attribute.html#for"},{"doc":"redraw/dom/attribute","title":"form_action","content":"pub fn form_action(action: String) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/button#formaction)\nSynonyms:\nredraw/dom/attribute.form_action\nredraw/dom/attribute form_action","url":"redraw/dom/attribute.html#form_action"},{"doc":"redraw/dom/attribute","title":"form_enctype","content":"pub fn form_enctype(value: String) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/button#formenctype)\nSynonyms:\nredraw/dom/attribute.form_enctype\nredraw/dom/attribute form_enctype","url":"redraw/dom/attribute.html#form_enctype"},{"doc":"redraw/dom/attribute","title":"form_method","content":"pub fn form_method(method: String) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/button#formmethod)\nSynonyms:\nredraw/dom/attribute.form_method\nredraw/dom/attribute form_method","url":"redraw/dom/attribute.html#form_method"},{"doc":"redraw/dom/attribute","title":"form_novalidate","content":"pub fn form_novalidate(value: Bool) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/button#formnovalidate)\nSynonyms:\nredraw/dom/attribute.form_novalidate\nredraw/dom/attribute form_novalidate","url":"redraw/dom/attribute.html#form_novalidate"},{"doc":"redraw/dom/attribute","title":"form_target","content":"pub fn form_target(target: String) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/button#formtarget)\nSynonyms:\nredraw/dom/attribute.form_target\nredraw/dom/attribute form_target","url":"redraw/dom/attribute.html#form_target"},{"doc":"redraw/dom/attribute","title":"height","content":"pub fn height(val: Int) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/HTMLObjectElement/height)\nSynonyms:\nredraw/dom/attribute.height\nredraw/dom/attribute height","url":"redraw/dom/attribute.html#height"},{"doc":"redraw/dom/attribute","title":"hidden","content":"pub fn hidden(value: Bool) -&gt; Attribute\n Specifies whether the element should be hidden. \\\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Global_attributes/hidden)\nSynonyms:\nredraw/dom/attribute.hidden\nredraw/dom/attribute hidden","url":"redraw/dom/attribute.html#hidden"},{"doc":"redraw/dom/attribute","title":"href","content":"pub fn href(url: String) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/HTMLAnchorElement/href)\nSynonyms:\nredraw/dom/attribute.href\nredraw/dom/attribute href","url":"redraw/dom/attribute.html#href"},{"doc":"redraw/dom/attribute","title":"html_for","content":"pub fn html_for(value: String) -&gt; Attribute\n Alias of `for`. \\\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Attributes/for)\nSynonyms:\nredraw/dom/attribute.html_for\nredraw/dom/attribute html_for","url":"redraw/dom/attribute.html#html_for"},{"doc":"redraw/dom/attribute","title":"id","content":"pub fn id(value: String) -&gt; Attribute\n Specifies a unique identifier for this element, which can be used to find\n it later or connect it with other elements. Generate it with useId to avoid\n clashes between multiple instances of the same component. \\\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Global_attributes/id)\nSynonyms:\nredraw/dom/attribute.id\nredraw/dom/attribute id","url":"redraw/dom/attribute.html#id"},{"doc":"redraw/dom/attribute","title":"inner_html","content":"pub fn inner_html(html: String) -&gt; InnerHTML\n The `inner_html` data should be created as close to where the HTML is\n generated as possible. This ensures that all raw HTML being used in your\n code is explicitly marked as such, and that only variables that you expect\n to contain HTML are passed to `dangerously_set_inner_html`. It is not\n recommended to create the object inline like\n `html.div([attribute.dangerously_set_inner_html(attribute.inner_html(markup))], [])` \\\n [Documentation](https://react.dev/reference/react-dom/components/common#dangerously-setting-the-inner-html)\nSynonyms:\nredraw/dom/attribute.inner_html\nredraw/dom/attribute inner_html","url":"redraw/dom/attribute.html#inner_html"},{"doc":"redraw/dom/attribute","title":"input_mode","content":"pub fn input_mode(value: String) -&gt; Attribute\n Specifies what kind of keyboard to display (for example, text, number or telephone). \\\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Global_attributes/inputmode)\nSynonyms:\nredraw/dom/attribute.input_mode\nredraw/dom/attribute input_mode","url":"redraw/dom/attribute.html#input_mode"},{"doc":"redraw/dom/attribute","title":"is","content":"pub fn is(value: String) -&gt; Attribute\n If specified, the component will behave like a custom element. \\\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Global_attributes/is)\nSynonyms:\nredraw/dom/attribute.is\nredraw/dom/attribute is","url":"redraw/dom/attribute.html#is"},{"doc":"redraw/dom/attribute","title":"item_prop","content":"pub fn item_prop(value: String) -&gt; Attribute\n Specifies which property the element represents for structured data crawlers. \\\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Global_attributes/itemprop)\nSynonyms:\nredraw/dom/attribute.item_prop\nredraw/dom/attribute item_prop","url":"redraw/dom/attribute.html#item_prop"},{"doc":"redraw/dom/attribute","title":"lang","content":"pub fn lang(value: String) -&gt; Attribute\n Specifies the language of the element. \\\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Global_attributes/lang)\nSynonyms:\nredraw/dom/attribute.lang\nredraw/dom/attribute lang","url":"redraw/dom/attribute.html#lang"},{"doc":"redraw/dom/attribute","title":"loop","content":"pub fn loop(should_loop: Bool) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/HTMLMediaElement/loop)\nSynonyms:\nredraw/dom/attribute.loop\nredraw/dom/attribute loop","url":"redraw/dom/attribute.html#loop"},{"doc":"redraw/dom/attribute","title":"max","content":"pub fn max(val: String) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Attributes/max)\nSynonyms:\nredraw/dom/attribute.max\nredraw/dom/attribute max","url":"redraw/dom/attribute.html#max"},{"doc":"redraw/dom/attribute","title":"method","content":"pub fn method(method: String) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/HTMLFormElement/method)\nSynonyms:\nredraw/dom/attribute.method\nredraw/dom/attribute method","url":"redraw/dom/attribute.html#method"},{"doc":"redraw/dom/attribute","title":"min","content":"pub fn min(val: String) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Attributes/min)\nSynonyms:\nredraw/dom/attribute.min\nredraw/dom/attribute min","url":"redraw/dom/attribute.html#min"},{"doc":"redraw/dom/attribute","title":"msg","content":"pub fn msg(uri: String) -&gt; Attribute\n\nSynonyms:\nredraw/dom/attribute.msg\nredraw/dom/attribute msg","url":"redraw/dom/attribute.html#msg"},{"doc":"redraw/dom/attribute","title":"name","content":"pub fn name(name: String) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/HTMLFormElement/name)\nSynonyms:\nredraw/dom/attribute.name\nredraw/dom/attribute name","url":"redraw/dom/attribute.html#name"},{"doc":"redraw/dom/attribute","title":"novalidate","content":"pub fn novalidate(value: Bool) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/HTMLFormElement/novalidate)\nSynonyms:\nredraw/dom/attribute.novalidate\nredraw/dom/attribute novalidate","url":"redraw/dom/attribute.html#novalidate"},{"doc":"redraw/dom/attribute","title":"open","content":"pub fn open(is_open: Bool) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/HTMLDetailsElement/open)\nSynonyms:\nredraw/dom/attribute.open\nredraw/dom/attribute open","url":"redraw/dom/attribute.html#open"},{"doc":"redraw/dom/attribute","title":"pattern","content":"pub fn pattern(regex: String) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Attributes/pattern)\nSynonyms:\nredraw/dom/attribute.pattern\nredraw/dom/attribute pattern","url":"redraw/dom/attribute.html#pattern"},{"doc":"redraw/dom/attribute","title":"placeholder","content":"pub fn placeholder(text: String) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Attributes/placeholder)\nSynonyms:\nredraw/dom/attribute.placeholder\nredraw/dom/attribute placeholder","url":"redraw/dom/attribute.html#placeholder"},{"doc":"redraw/dom/attribute","title":"readonly","content":"pub fn readonly(is_readonly: Bool) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Attributes/readonly)\nSynonyms:\nredraw/dom/attribute.readonly\nredraw/dom/attribute readonly","url":"redraw/dom/attribute.html#readonly"},{"doc":"redraw/dom/attribute","title":"ref","content":"pub fn ref(ref: Ref(Option(a))) -&gt; Attribute\n A ref object from `redraw.use_ref`. Your ref will be filled with the DOM\n element for this node. Contrarily to JS React, when using a Ref, you&#39;re\n forced to use an optional type here. Because when using this function, you\n want to get a reference from a real DOM node, meaning at the initialization\n of the reference, you won&#39;t have any data. Use `ref_` when you want full\n control over the ref you send to the Component. \\\n [Documentation](https://react.dev/reference/react-dom/components/common#manipulating-a-dom-node-with-a-ref)\nSynonyms:\nredraw/dom/attribute.ref\nredraw/dom/attribute ref","url":"redraw/dom/attribute.html#ref"},{"doc":"redraw/dom/attribute","title":"ref_","content":"pub fn ref_(ref: fn(a) -&gt; Nil) -&gt; Attribute\n A ref callback function. The callback will be provided with the DOM element\n for this node. Use this function to get control on the ref provided by the\n DOM node or the component. \\\n [Documentation](https://react.dev/reference/react-dom/components/common#manipulating-a-dom-node-with-a-ref)\nSynonyms:\nredraw/dom/attribute.ref_\nredraw/dom/attribute ref_","url":"redraw/dom/attribute.html#ref_"},{"doc":"redraw/dom/attribute","title":"rel","content":"pub fn rel(relationship: String) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Attributes/rel)\nSynonyms:\nredraw/dom/attribute.rel\nredraw/dom/attribute rel","url":"redraw/dom/attribute.html#rel"},{"doc":"redraw/dom/attribute","title":"required","content":"pub fn required(is_required: Bool) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Attributes/required)\nSynonyms:\nredraw/dom/attribute.required\nredraw/dom/attribute required","url":"redraw/dom/attribute.html#required"},{"doc":"redraw/dom/attribute","title":"role","content":"pub fn role(value: String) -&gt; Attribute\n Specifies the element role explicitly for assistive technologies.\nSynonyms:\nredraw/dom/attribute.role\nredraw/dom/attribute role","url":"redraw/dom/attribute.html#role"},{"doc":"redraw/dom/attribute","title":"rows","content":"pub fn rows(val: Int) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/HTMLTextAreaElement/rows)\nSynonyms:\nredraw/dom/attribute.rows\nredraw/dom/attribute rows","url":"redraw/dom/attribute.html#rows"},{"doc":"redraw/dom/attribute","title":"selected","content":"pub fn selected(is_selected: Bool) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/option#selected)\nSynonyms:\nredraw/dom/attribute.selected\nredraw/dom/attribute selected","url":"redraw/dom/attribute.html#selected"},{"doc":"redraw/dom/attribute","title":"slot","content":"pub fn slot(value: String) -&gt; Attribute\n Specifies the slot name when using shadow DOM. \\\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Global_attributes/slot)\nSynonyms:\nredraw/dom/attribute.slot\nredraw/dom/attribute slot","url":"redraw/dom/attribute.html#slot"},{"doc":"redraw/dom/attribute","title":"spell_check","content":"pub fn spell_check(value: Bool) -&gt; Attribute\n If explicitly set to true or false, enables or disables spellchecking. \\\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Global_attributes/spellcheck)\nSynonyms:\nredraw/dom/attribute.spell_check\nredraw/dom/attribute spell_check","url":"redraw/dom/attribute.html#spell_check"},{"doc":"redraw/dom/attribute","title":"src","content":"pub fn src(value: String) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/HTMLMediaElement/src)\nSynonyms:\nredraw/dom/attribute.src\nredraw/dom/attribute src","url":"redraw/dom/attribute.html#src"},{"doc":"redraw/dom/attribute","title":"step","content":"pub fn step(val: String) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Attributes/step)\nSynonyms:\nredraw/dom/attribute.step\nredraw/dom/attribute step","url":"redraw/dom/attribute.html#step"},{"doc":"redraw/dom/attribute","title":"style","content":"pub fn style(styles: List(#(String, String))) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Global_attributes/style)\nSynonyms:\nredraw/dom/attribute.style\nredraw/dom/attribute style","url":"redraw/dom/attribute.html#style"},{"doc":"redraw/dom/attribute","title":"suppress_content_editable_warning","content":"pub fn suppress_content_editable_warning(\n  value: Bool,\n) -&gt; Attribute\n If `True`, suppresses the warning that React shows for elements that both\n have `children` and `content_editable(True)` (which normally do not work\n together). Use this if you’re building a text input library that manages\n the `contentEditable` content manually.\nSynonyms:\nredraw/dom/attribute.suppress_content_editable_warning\nredraw/dom/attribute suppress_content_editable_warning","url":"redraw/dom/attribute.html#suppress_content_editable_warning"},{"doc":"redraw/dom/attribute","title":"suppress_hydration_warning","content":"pub fn suppress_hydration_warning(value: Bool) -&gt; Attribute\n If you use [server rendering](https://react.dev/reference/react-dom/server),\n normally there is a warning when the server and the client render different\n content. In some rare cases (like timestamps), it is very hard or impossible\n to guarantee an exact match. If you set suppressHydrationWarning to true,\n React will not warn you about mismatches in the attributes and the content\n of that element. It only works one level deep, and is intended to be used\n as an escape hatch. Don’t overuse it.\n [Read about suppressing hydration errors.](https://react.dev/reference/react-dom/client/hydrateRoot#suppressing-unavoidable-hydration-mismatch-errors)\nSynonyms:\nredraw/dom/attribute.suppress_hydration_warning\nredraw/dom/attribute suppress_hydration_warning","url":"redraw/dom/attribute.html#suppress_hydration_warning"},{"doc":"redraw/dom/attribute","title":"tab_index","content":"pub fn tab_index(value: Int) -&gt; Attribute\n Overrides the default Tab button behavior. Avoid using values other than -1 and 0. \\\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Global_attributes/tabindex)\nSynonyms:\nredraw/dom/attribute.tab_index\nredraw/dom/attribute tab_index","url":"redraw/dom/attribute.html#tab_index"},{"doc":"redraw/dom/attribute","title":"target","content":"pub fn target(value: String) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/HTMLAnchorElement/target)\nSynonyms:\nredraw/dom/attribute.target\nredraw/dom/attribute target","url":"redraw/dom/attribute.html#target"},{"doc":"redraw/dom/attribute","title":"title","content":"pub fn title(value: String) -&gt; Attribute\n Specifies the tooltip text for the element. \\\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Global_attributes/title)\nSynonyms:\nredraw/dom/attribute.title\nredraw/dom/attribute title","url":"redraw/dom/attribute.html#title"},{"doc":"redraw/dom/attribute","title":"translate","content":"pub fn translate(value: Translate) -&gt; Attribute\n Passing No excludes the element content from being translated. \\\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Global_attributes/translate)\nSynonyms:\nredraw/dom/attribute.translate\nredraw/dom/attribute translate","url":"redraw/dom/attribute.html#translate"},{"doc":"redraw/dom/attribute","title":"type_","content":"pub fn type_(name: String) -&gt; Attribute\n Type of an `input`. Value can be\n [`&quot;button&quot;`](https://developer.mozilla.org/docs/Web/HTML/Element/input/button),\n [`&quot;checkbox&quot;`](https://developer.mozilla.org/docs/Web/HTML/Element/input/checkbox),\n [`&quot;color&quot;`](https://developer.mozilla.org/docs/Web/HTML/Element/input/color),\n [`&quot;date&quot;`](https://developer.mozilla.org/docs/Web/HTML/Element/input/date),\n [`&quot;datetime-local&quot;`](https://developer.mozilla.org/docs/Web/HTML/Element/input/datetime-local),\n [`&quot;email&quot;`](https://developer.mozilla.org/docs/Web/HTML/Element/input/email),\n [`&quot;file&quot;`](https://developer.mozilla.org/docs/Web/HTML/Element/input/file),\n [`&quot;hidden&quot;`](https://developer.mozilla.org/docs/Web/HTML/Element/input/hidden),\n [`&quot;image&quot;`](https://developer.mozilla.org/docs/Web/HTML/Element/input/image),\n [`&quot;month&quot;`](https://developer.mozilla.org/docs/Web/HTML/Element/input/month),\n [`&quot;number&quot;`](https://developer.mozilla.org/docs/Web/HTML/Element/input/number),\n [`&quot;password&quot;`](https://developer.mozilla.org/docs/Web/HTML/Element/input/password),\n [`&quot;radio&quot;`](https://developer.mozilla.org/docs/Web/HTML/Element/input/radio),\n [`&quot;range&quot;`](https://developer.mozilla.org/docs/Web/HTML/Element/input/range),\n [`&quot;reset&quot;`](https://developer.mozilla.org/docs/Web/HTML/Element/input/reset),\n [`&quot;search&quot;`](https://developer.mozilla.org/docs/Web/HTML/Element/input/search),\n [`&quot;submit&quot;`](https://developer.mozilla.org/docs/Web/HTML/Element/input/submit),\n [`&quot;tel&quot;`](https://developer.mozilla.org/docs/Web/HTML/Element/input/tel),\n [`&quot;text&quot;`](https://developer.mozilla.org/docs/Web/HTML/Element/input/text),\n [`&quot;time&quot;`](https://developer.mozilla.org/docs/Web/HTML/Element/input/time),\n [`&quot;url&quot;`](https://developer.mozilla.org/docs/Web/HTML/Element/input/url), or\n [`&quot;week&quot;`](https://developer.mozilla.org/docs/Web/HTML/Element/input/week).\nSynonyms:\nredraw/dom/attribute.type_\nredraw/dom/attribute type_","url":"redraw/dom/attribute.html#type_"},{"doc":"redraw/dom/attribute","title":"value","content":"pub fn value(val: String) -&gt; Attribute\n [Input Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/input#value) \\\n [Button Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/button#value)\nSynonyms:\nredraw/dom/attribute.value\nredraw/dom/attribute value","url":"redraw/dom/attribute.html#value"},{"doc":"redraw/dom/attribute","title":"width","content":"pub fn width(val: Int) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/HTMLObjectElement/width)\nSynonyms:\nredraw/dom/attribute.width\nredraw/dom/attribute width","url":"redraw/dom/attribute.html#width"},{"doc":"redraw/dom/attribute","title":"wrap","content":"pub fn wrap(mode: String) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/HTMLTextAreaElement/wrap)\nSynonyms:\nredraw/dom/attribute.wrap\nredraw/dom/attribute wrap","url":"redraw/dom/attribute.html#wrap"},{"doc":"redraw/dom/attribute","title":"redraw/dom/attribute","content":" Implementation for HTML and SVG attributes usable in React and in browser.\n Contrarily to Lustre, every attributes can take arbitrary data, because\n they&#39;re directly bind in the underlying component&#39;s props.\n\n All available attributes can be found in the\n [React.dev](https://react.dev/reference/react-dom/components/common#common)\n documentation for detailed information, as well as on\n [MDN](https://developer.mozilla.org/docs/Web/API/Element).","url":"redraw/dom/attribute.html"},{"doc":"redraw/dom/client","title":"Root","content":"pub type Root\n Root to display React DOM. \\\n [Documentation](https://react.dev/reference/react-dom/client/createRoot#createroot)\n\nSynonyms:\nredraw/dom/client.Root\nredraw/dom/client Root","url":"redraw/dom/client.html#Root"},{"doc":"redraw/dom/client","title":"create_root","content":"pub fn create_root(root: String) -&gt; Result(Root, Nil)\n Let you create a root to display React components inside a browser DOM node.\n Contrarily to JavaScript, `create_root` returns a `Result` to avoid runtime\n error. Indeed, when the provided root does not exist in your HTML, `create_root`\n fails. You should never assume `create_root` will work out-of-the-box when\n you&#39;re building a library. Otherwise, you could assert the resulting\n value in your application.\n\n \n import redraw/dom/client\n\n pub fn main() {\n   let assert Ok(root) = client.create_root(&quot;app&quot;)\n   client.render(root, app())\n }\n \n\n [Documentation](https://react.dev/reference/react-dom/client/createRoot)\nSynonyms:\nredraw/dom/client.create_root\nredraw/dom/client create_root","url":"redraw/dom/client.html#create_root"},{"doc":"redraw/dom/client","title":"hydrate_root","content":"pub fn hydrate_root(\n  root: String,\n  node: Component,\n) -&gt; Result(Root, Nil)\n Let you display React components inside a browser DOM node whose HTML content\n was previously generated by `react-dom/server`.\n Contrarily to JavaScript, `hydrate_root` returns a `Result` to avoid runtime\n error. Indeed, when the provided root does not exist in your HTML, `hydrate_root`\n fails. You should never assume `hydrate_root` will work out-of-the-box when\n you&#39;re building a library. Otherwise, you could assert the resulting\n value in your application.\n\n \n import redraw/dom/client\n\n pub fn main() {\n   let assert Ok(root) = client.hydrate_root(&quot;app&quot;)\n }\n \n\n [Documentation](https://react.dev/reference/react-dom/client/hydrateRoot)\nSynonyms:\nredraw/dom/client.hydrate_root\nredraw/dom/client hydrate_root","url":"redraw/dom/client.html#hydrate_root"},{"doc":"redraw/dom/client","title":"render","content":"pub fn render(root: Root, child: Component) -&gt; Nil\n Call `render(root)` to display a piece of JSX (“React node”) into the React\n root’s browser DOM node. \\\n [Documentation](https://react.dev/reference/react-dom/client/createRoot#root-render)\nSynonyms:\nredraw/dom/client.render\nredraw/dom/client render","url":"redraw/dom/client.html#render"},{"doc":"redraw/dom/client","title":"redraw/dom/client","content":"","url":"redraw/dom/client.html"},{"doc":"redraw/dom/event/animation","title":"AnimationEvent","content":"pub type AnimationEvent\n [Documentation](https://developer.mozilla.org/docs/Web/API/AnimationEvent)\n\nSynonyms:\nredraw/dom/event/animation.AnimationEvent\nredraw/dom/event/animation AnimationEvent","url":"redraw/dom/event/animation.html#AnimationEvent"},{"doc":"redraw/dom/event/animation","title":"animation_name","content":"pub fn animation_name(event: AnimationEvent) -&gt; String\n [Documentation](https://developer.mozilla.org/docs/Web/API/AnimationEvent/animationName)\nSynonyms:\nredraw/dom/event/animation.animation_name\nredraw/dom/event/animation animation_name","url":"redraw/dom/event/animation.html#animation_name"},{"doc":"redraw/dom/event/animation","title":"as_event","content":"pub fn as_event(event: AnimationEvent) -&gt; Event\n `AnimationEvent` inherits `Event`.\nSynonyms:\nredraw/dom/event/animation.as_event\nredraw/dom/event/animation as_event","url":"redraw/dom/event/animation.html#as_event"},{"doc":"redraw/dom/event/animation","title":"elapsed_time","content":"pub fn elapsed_time(event: AnimationEvent) -&gt; Float\n [Documentation](https://developer.mozilla.org/docs/Web/API/AnimationEvent/elapsedTime)\nSynonyms:\nredraw/dom/event/animation.elapsed_time\nredraw/dom/event/animation elapsed_time","url":"redraw/dom/event/animation.html#elapsed_time"},{"doc":"redraw/dom/event/animation","title":"pseudo_element","content":"pub fn pseudo_element(event: AnimationEvent) -&gt; String\n [Documentation](https://developer.mozilla.org/docs/Web/API/AnimationEvent/pseudoElement)\nSynonyms:\nredraw/dom/event/animation.pseudo_element\nredraw/dom/event/animation pseudo_element","url":"redraw/dom/event/animation.html#pseudo_element"},{"doc":"redraw/dom/event/animation","title":"redraw/dom/event/animation","content":" The `AnimationEvent` interface represents events providing information\n related to [animations](https://developer.mozilla.org/docs/Web/CSS/CSS_animations/Using_CSS_animations).","url":"redraw/dom/event/animation.html"},{"doc":"redraw/dom/event/clipboard","title":"ClipboardEvent","content":"pub type ClipboardEvent\n [Documentation](https://developer.mozilla.org/docs/Web/API/ClipboardEvent)\n\nSynonyms:\nredraw/dom/event/clipboard.ClipboardEvent\nredraw/dom/event/clipboard ClipboardEvent","url":"redraw/dom/event/clipboard.html#ClipboardEvent"},{"doc":"redraw/dom/event/clipboard","title":"as_event","content":"pub fn as_event(event: ClipboardEvent) -&gt; Event\n `ClipboardEvent` inherits `Event`.\nSynonyms:\nredraw/dom/event/clipboard.as_event\nredraw/dom/event/clipboard as_event","url":"redraw/dom/event/clipboard.html#as_event"},{"doc":"redraw/dom/event/clipboard","title":"clipboard_data","content":"pub fn clipboard_data(event: ClipboardEvent) -&gt; Dynamic\n [Documentation](https://developer.mozilla.org/docs/Web/API/ClipboardEvent/clipboardData)\nSynonyms:\nredraw/dom/event/clipboard.clipboard_data\nredraw/dom/event/clipboard clipboard_data","url":"redraw/dom/event/clipboard.html#clipboard_data"},{"doc":"redraw/dom/event/clipboard","title":"redraw/dom/event/clipboard","content":" The `ClipboardEvent` interface of the [Clipboard API](https://developer.mozilla.org/docs/Web/API/Clipboard_API) represents events\n providing information related to modification of the clipboard, that is\n [`cut`](https://developer.mozilla.org/docs/Web/API/Element/cut_event),\n [`copy`](https://developer.mozilla.org/docs/Web/API/Element/cut_event), and\n [`paste`](https://developer.mozilla.org/docs/Web/API/Element/cut_event) events.","url":"redraw/dom/event/clipboard.html"},{"doc":"redraw/dom/event/composition","title":"CompositionEvent","content":"pub type CompositionEvent\n [Documentation](https://developer.mozilla.org/docs/Web/API/CompositionEvent)\n\nSynonyms:\nredraw/dom/event/composition.CompositionEvent\nredraw/dom/event/composition CompositionEvent","url":"redraw/dom/event/composition.html#CompositionEvent"},{"doc":"redraw/dom/event/composition","title":"as_event","content":"pub fn as_event(event: CompositionEvent) -&gt; Event\n `CompositionEvent` inherits `Event`.\nSynonyms:\nredraw/dom/event/composition.as_event\nredraw/dom/event/composition as_event","url":"redraw/dom/event/composition.html#as_event"},{"doc":"redraw/dom/event/composition","title":"data","content":"pub fn data(event: CompositionEvent) -&gt; String\n [Documentation](https://developer.mozilla.org/docs/Web/API/CompositionEvent/data)\nSynonyms:\nredraw/dom/event/composition.data\nredraw/dom/event/composition data","url":"redraw/dom/event/composition.html#data"},{"doc":"redraw/dom/event/composition","title":"redraw/dom/event/composition","content":" The DOM `CompositionEvent` represents events that occur due to the user\n indirectly entering text.\n\n [Input Method Editor Documentation](https://developer.mozilla.org/docs/Glossary/Input_method_editor).","url":"redraw/dom/event/composition.html"},{"doc":"redraw/dom/event/ui","title":"UIEvent","content":"pub type UIEvent\n [Documentation](https://developer.mozilla.org/docs/Web/API/UIEvent)\n\nSynonyms:\nredraw/dom/event/ui.UIEvent\nredraw/dom/event/ui UIEvent","url":"redraw/dom/event/ui.html#UIEvent"},{"doc":"redraw/dom/event/ui","title":"as_event","content":"pub fn as_event(event: UIEvent) -&gt; Event\n `UIEvent` inherits `Event`.\nSynonyms:\nredraw/dom/event/ui.as_event\nredraw/dom/event/ui as_event","url":"redraw/dom/event/ui.html#as_event"},{"doc":"redraw/dom/event/ui","title":"detail","content":"pub fn detail(event: UIEvent) -&gt; Int\n [Documentation](https://developer.mozilla.org/docs/Web/API/UIEvent/detail)\nSynonyms:\nredraw/dom/event/ui.detail\nredraw/dom/event/ui detail","url":"redraw/dom/event/ui.html#detail"},{"doc":"redraw/dom/event/ui","title":"view","content":"pub fn view(event: UIEvent) -&gt; Dynamic\n [Documentation](https://developer.mozilla.org/docs/Web/API/UIEvent/view)\nSynonyms:\nredraw/dom/event/ui.view\nredraw/dom/event/ui view","url":"redraw/dom/event/ui.html#view"},{"doc":"redraw/dom/event/ui","title":"redraw/dom/event/ui","content":" The `UIEvent` interface represents simple user interface events.","url":"redraw/dom/event/ui.html"},{"doc":"redraw/dom/event/mouse","title":"MouseEvent","content":"pub type MouseEvent\n [Documentation](https://developer.mozilla.org/docs/Web/API/MouseEvent)\n\nSynonyms:\nredraw/dom/event/mouse.MouseEvent\nredraw/dom/event/mouse MouseEvent","url":"redraw/dom/event/mouse.html#MouseEvent"},{"doc":"redraw/dom/event/mouse","title":"alt_key","content":"pub fn alt_key(event: MouseEvent) -&gt; Bool\n [Documentation](https://developer.mozilla.org/docs/Web/API/MouseEvent/altKey)\nSynonyms:\nredraw/dom/event/mouse.alt_key\nredraw/dom/event/mouse alt_key","url":"redraw/dom/event/mouse.html#alt_key"},{"doc":"redraw/dom/event/mouse","title":"as_event","content":"pub fn as_event(event: MouseEvent) -&gt; Event\n `MouseEvent` inherits `Event`.\nSynonyms:\nredraw/dom/event/mouse.as_event\nredraw/dom/event/mouse as_event","url":"redraw/dom/event/mouse.html#as_event"},{"doc":"redraw/dom/event/mouse","title":"as_ui_event","content":"pub fn as_ui_event(event: MouseEvent) -&gt; UIEvent\n `MouseEvent` inherits `UIEvent`.\nSynonyms:\nredraw/dom/event/mouse.as_ui_event\nredraw/dom/event/mouse as_ui_event","url":"redraw/dom/event/mouse.html#as_ui_event"},{"doc":"redraw/dom/event/mouse","title":"button","content":"pub fn button(event: MouseEvent) -&gt; Int\n [Documentation](https://developer.mozilla.org/docs/Web/API/MouseEvent/button)\nSynonyms:\nredraw/dom/event/mouse.button\nredraw/dom/event/mouse button","url":"redraw/dom/event/mouse.html#button"},{"doc":"redraw/dom/event/mouse","title":"buttons","content":"pub fn buttons(event: MouseEvent) -&gt; Int\n [Documentation](https://developer.mozilla.org/docs/Web/API/MouseEvent/buttons)\nSynonyms:\nredraw/dom/event/mouse.buttons\nredraw/dom/event/mouse buttons","url":"redraw/dom/event/mouse.html#buttons"},{"doc":"redraw/dom/event/mouse","title":"client_x","content":"pub fn client_x(event: MouseEvent) -&gt; Float\n [Documentation](https://developer.mozilla.org/docs/Web/API/MouseEvent/clientX)\nSynonyms:\nredraw/dom/event/mouse.client_x\nredraw/dom/event/mouse client_x","url":"redraw/dom/event/mouse.html#client_x"},{"doc":"redraw/dom/event/mouse","title":"client_y","content":"pub fn client_y(event: MouseEvent) -&gt; Float\n [Documentation](https://developer.mozilla.org/docs/Web/API/MouseEvent/clientY)\nSynonyms:\nredraw/dom/event/mouse.client_y\nredraw/dom/event/mouse client_y","url":"redraw/dom/event/mouse.html#client_y"},{"doc":"redraw/dom/event/mouse","title":"ctrl_key","content":"pub fn ctrl_key(event: MouseEvent) -&gt; Bool\n [Documentation](https://developer.mozilla.org/docs/Web/API/MouseEvent/ctrlKey)\nSynonyms:\nredraw/dom/event/mouse.ctrl_key\nredraw/dom/event/mouse ctrl_key","url":"redraw/dom/event/mouse.html#ctrl_key"},{"doc":"redraw/dom/event/mouse","title":"get_modifier_state","content":"pub fn get_modifier_state(event: MouseEvent, key: String) -&gt; Bool\n [Documentation](https://developer.mozilla.org/docs/Web/API/MouseEvent/getModifierState)\nSynonyms:\nredraw/dom/event/mouse.get_modifier_state\nredraw/dom/event/mouse get_modifier_state","url":"redraw/dom/event/mouse.html#get_modifier_state"},{"doc":"redraw/dom/event/mouse","title":"meta_key","content":"pub fn meta_key(event: MouseEvent) -&gt; Bool\n [Documentation](https://developer.mozilla.org/docs/Web/API/MouseEvent/metaKey)\nSynonyms:\nredraw/dom/event/mouse.meta_key\nredraw/dom/event/mouse meta_key","url":"redraw/dom/event/mouse.html#meta_key"},{"doc":"redraw/dom/event/mouse","title":"movement_x","content":"pub fn movement_x(event: MouseEvent) -&gt; Int\n [Documentation](https://developer.mozilla.org/docs/Web/API/MouseEvent/movementX)\nSynonyms:\nredraw/dom/event/mouse.movement_x\nredraw/dom/event/mouse movement_x","url":"redraw/dom/event/mouse.html#movement_x"},{"doc":"redraw/dom/event/mouse","title":"movement_y","content":"pub fn movement_y(event: MouseEvent) -&gt; Int\n [Documentation](https://developer.mozilla.org/docs/Web/API/MouseEvent/movementY)\nSynonyms:\nredraw/dom/event/mouse.movement_y\nredraw/dom/event/mouse movement_y","url":"redraw/dom/event/mouse.html#movement_y"},{"doc":"redraw/dom/event/mouse","title":"offset_x","content":"pub fn offset_x(event: MouseEvent) -&gt; Float\n [Documentation](https://developer.mozilla.org/docs/Web/API/MouseEvent/offsetX)\nSynonyms:\nredraw/dom/event/mouse.offset_x\nredraw/dom/event/mouse offset_x","url":"redraw/dom/event/mouse.html#offset_x"},{"doc":"redraw/dom/event/mouse","title":"offset_y","content":"pub fn offset_y(event: MouseEvent) -&gt; Float\n [Documentation](https://developer.mozilla.org/docs/Web/API/MouseEvent/offsetY)\nSynonyms:\nredraw/dom/event/mouse.offset_y\nredraw/dom/event/mouse offset_y","url":"redraw/dom/event/mouse.html#offset_y"},{"doc":"redraw/dom/event/mouse","title":"page_x","content":"pub fn page_x(event: MouseEvent) -&gt; Float\n [Documentation](https://developer.mozilla.org/docs/Web/API/MouseEvent/pageX)\nSynonyms:\nredraw/dom/event/mouse.page_x\nredraw/dom/event/mouse page_x","url":"redraw/dom/event/mouse.html#page_x"},{"doc":"redraw/dom/event/mouse","title":"page_y","content":"pub fn page_y(event: MouseEvent) -&gt; Float\n [Documentation](https://developer.mozilla.org/docs/Web/API/MouseEvent/pageY)\nSynonyms:\nredraw/dom/event/mouse.page_y\nredraw/dom/event/mouse page_y","url":"redraw/dom/event/mouse.html#page_y"},{"doc":"redraw/dom/event/mouse","title":"related_target","content":"pub fn related_target(event: MouseEvent) -&gt; Dynamic\n [Documentation](https://developer.mozilla.org/docs/Web/API/MouseEvent/relatedTarget)\nSynonyms:\nredraw/dom/event/mouse.related_target\nredraw/dom/event/mouse related_target","url":"redraw/dom/event/mouse.html#related_target"},{"doc":"redraw/dom/event/mouse","title":"screen_x","content":"pub fn screen_x(event: MouseEvent) -&gt; Float\n [Documentation](https://developer.mozilla.org/docs/Web/API/MouseEvent/screenX)\nSynonyms:\nredraw/dom/event/mouse.screen_x\nredraw/dom/event/mouse screen_x","url":"redraw/dom/event/mouse.html#screen_x"},{"doc":"redraw/dom/event/mouse","title":"screen_y","content":"pub fn screen_y(event: MouseEvent) -&gt; Float\n [Documentation](https://developer.mozilla.org/docs/Web/API/MouseEvent/screenY)\nSynonyms:\nredraw/dom/event/mouse.screen_y\nredraw/dom/event/mouse screen_y","url":"redraw/dom/event/mouse.html#screen_y"},{"doc":"redraw/dom/event/mouse","title":"shift_key","content":"pub fn shift_key(event: MouseEvent) -&gt; Bool\n [Documentation](https://developer.mozilla.org/docs/Web/API/MouseEvent/shiftKey)\nSynonyms:\nredraw/dom/event/mouse.shift_key\nredraw/dom/event/mouse shift_key","url":"redraw/dom/event/mouse.html#shift_key"},{"doc":"redraw/dom/event/mouse","title":"redraw/dom/event/mouse","content":" The `MouseEvent` interface represents events that occur due to the user\n interacting with a pointing device (such as a mouse). Common events using\n this interface include [`click`](https://developer.mozilla.org/docs/Web/API/Element/click_event),\n [`dblclick`](https://developer.mozilla.org/docs/Web/API/Element/dblclick_event),\n [`mouseup`](https://developer.mozilla.org/docs/Web/API/Element/mouseup_event),\n [`mousedown`](https://developer.mozilla.org/docs/Web/API/Element/mousedown_event).","url":"redraw/dom/event/mouse.html"},{"doc":"redraw/dom/event/drag","title":"DragEvent","content":"pub type DragEvent\n [Documentation](https://developer.mozilla.org/docs/Web/API/DragEvent)\n\nSynonyms:\nredraw/dom/event/drag.DragEvent\nredraw/dom/event/drag DragEvent","url":"redraw/dom/event/drag.html#DragEvent"},{"doc":"redraw/dom/event/drag","title":"as_event","content":"pub fn as_event(event: DragEvent) -&gt; Event\n `DragEvent` inherits `Event`.\nSynonyms:\nredraw/dom/event/drag.as_event\nredraw/dom/event/drag as_event","url":"redraw/dom/event/drag.html#as_event"},{"doc":"redraw/dom/event/drag","title":"as_mouse_event","content":"pub fn as_mouse_event(event: DragEvent) -&gt; MouseEvent\n `DragEvent` inherits from `MouseEvent`.\nSynonyms:\nredraw/dom/event/drag.as_mouse_event\nredraw/dom/event/drag as_mouse_event","url":"redraw/dom/event/drag.html#as_mouse_event"},{"doc":"redraw/dom/event/drag","title":"as_ui_event","content":"pub fn as_ui_event(event: DragEvent) -&gt; UIEvent\n `DragEvent` inherits from `UIEvent`.\nSynonyms:\nredraw/dom/event/drag.as_ui_event\nredraw/dom/event/drag as_ui_event","url":"redraw/dom/event/drag.html#as_ui_event"},{"doc":"redraw/dom/event/drag","title":"data_transfer","content":"pub fn data_transfer(event: DragEvent) -&gt; Dynamic\n [Documentation](https://developer.mozilla.org/docs/Web/API/DragEvent/dataTransfer)\nSynonyms:\nredraw/dom/event/drag.data_transfer\nredraw/dom/event/drag data_transfer","url":"redraw/dom/event/drag.html#data_transfer"},{"doc":"redraw/dom/event/drag","title":"redraw/dom/event/drag","content":" The `DragEvent` interface is a DOM event that represents a drag and drop\n interaction. The user initiates a drag by placing a pointer device (such as\n a mouse) on the touch surface and then dragging the pointer to a new\n location (such as another DOM element). Applications are free to interpret\n a drag and drop interaction in an application-specific way.\n\n [Drag and Drop API Documentation](https://developer.mozilla.org/docs/Web/API/HTML_Drag_and_Drop_API)","url":"redraw/dom/event/drag.html"},{"doc":"redraw/dom/event/focus","title":"FocusEvent","content":"pub type FocusEvent\n [Documentation](https://developer.mozilla.org/docs/Web/API/FocusEvent)\n\nSynonyms:\nredraw/dom/event/focus.FocusEvent\nredraw/dom/event/focus FocusEvent","url":"redraw/dom/event/focus.html#FocusEvent"},{"doc":"redraw/dom/event/focus","title":"as_event","content":"pub fn as_event(event: FocusEvent) -&gt; Event\n `FocusEvent` inherits `Event`.\nSynonyms:\nredraw/dom/event/focus.as_event\nredraw/dom/event/focus as_event","url":"redraw/dom/event/focus.html#as_event"},{"doc":"redraw/dom/event/focus","title":"as_ui_event","content":"pub fn as_ui_event(event: FocusEvent) -&gt; UIEvent\n `FocusEvent` inherits `UIEvent`.\nSynonyms:\nredraw/dom/event/focus.as_ui_event\nredraw/dom/event/focus as_ui_event","url":"redraw/dom/event/focus.html#as_ui_event"},{"doc":"redraw/dom/event/focus","title":"related_target","content":"pub fn related_target(event: FocusEvent) -&gt; Dynamic\n [Documentation](https://developer.mozilla.org/docs/Web/API/FocusEvent/relatedTarget)\nSynonyms:\nredraw/dom/event/focus.related_target\nredraw/dom/event/focus related_target","url":"redraw/dom/event/focus.html#related_target"},{"doc":"redraw/dom/event/focus","title":"redraw/dom/event/focus","content":" The `FocusEvent` interface represents focus-related events, including\n [`focus`](https://developer.mozilla.org/en-US/docs/Web/API/Element/focus_event),\n [`blur`](https://developer.mozilla.org/en-US/docs/Web/API/Element/blur_event),\n [`focusin`](https://developer.mozilla.org/en-US/docs/Web/API/Element/focusin_event),\n and [`focusout`](https://developer.mozilla.org/en-US/docs/Web/API/Element/focusout_event).","url":"redraw/dom/event/focus.html"},{"doc":"redraw/dom/event/input","title":"InputEvent","content":"pub type InputEvent\n [Documentation](https://developer.mozilla.org/docs/Web/API/InputEvent)\n\nSynonyms:\nredraw/dom/event/input.InputEvent\nredraw/dom/event/input InputEvent","url":"redraw/dom/event/input.html#InputEvent"},{"doc":"redraw/dom/event/input","title":"as_event","content":"pub fn as_event(event: InputEvent) -&gt; Event\n `InputEvent` inherits `Event`.\nSynonyms:\nredraw/dom/event/input.as_event\nredraw/dom/event/input as_event","url":"redraw/dom/event/input.html#as_event"},{"doc":"redraw/dom/event/input","title":"data","content":"pub fn data(event: InputEvent) -&gt; String\n [Documentation](https://developer.mozilla.org/docs/Web/API/InputEvent/data)\nSynonyms:\nredraw/dom/event/input.data\nredraw/dom/event/input data","url":"redraw/dom/event/input.html#data"},{"doc":"redraw/dom/event/input","title":"redraw/dom/event/input","content":" The `InputEvent` interface represents an event notifying the user of editable content changes.","url":"redraw/dom/event/input.html"},{"doc":"redraw/dom/event/keyboard","title":"KeyboardEvent","content":"pub type KeyboardEvent\n [Documentation](https://developer.mozilla.org/docs/Web/API/KeyboardEvent)\n\nSynonyms:\nredraw/dom/event/keyboard.KeyboardEvent\nredraw/dom/event/keyboard KeyboardEvent","url":"redraw/dom/event/keyboard.html#KeyboardEvent"},{"doc":"redraw/dom/event/keyboard","title":"alt_key","content":"pub fn alt_key(event: KeyboardEvent) -&gt; Bool\n [Documentation](https://developer.mozilla.org/docs/Web/API/KeyboardEvent/altKey)\nSynonyms:\nredraw/dom/event/keyboard.alt_key\nredraw/dom/event/keyboard alt_key","url":"redraw/dom/event/keyboard.html#alt_key"},{"doc":"redraw/dom/event/keyboard","title":"as_event","content":"pub fn as_event(event: KeyboardEvent) -&gt; Event\n `KeyboardEvent` inherits `Event`.\nSynonyms:\nredraw/dom/event/keyboard.as_event\nredraw/dom/event/keyboard as_event","url":"redraw/dom/event/keyboard.html#as_event"},{"doc":"redraw/dom/event/keyboard","title":"as_ui_event","content":"pub fn as_ui_event(event: KeyboardEvent) -&gt; UIEvent\n `KeyboardEvent` inherits `UIEvent`.\nSynonyms:\nredraw/dom/event/keyboard.as_ui_event\nredraw/dom/event/keyboard as_ui_event","url":"redraw/dom/event/keyboard.html#as_ui_event"},{"doc":"redraw/dom/event/keyboard","title":"code","content":"pub fn code(event: KeyboardEvent) -&gt; String\n [Documentation](https://developer.mozilla.org/docs/Web/API/KeyboardEvent/code)\nSynonyms:\nredraw/dom/event/keyboard.code\nredraw/dom/event/keyboard code","url":"redraw/dom/event/keyboard.html#code"},{"doc":"redraw/dom/event/keyboard","title":"ctrl_key","content":"pub fn ctrl_key(event: KeyboardEvent) -&gt; Bool\n [Documentation](https://developer.mozilla.org/docs/Web/API/KeyboardEvent/ctrlKey)\nSynonyms:\nredraw/dom/event/keyboard.ctrl_key\nredraw/dom/event/keyboard ctrl_key","url":"redraw/dom/event/keyboard.html#ctrl_key"},{"doc":"redraw/dom/event/keyboard","title":"get_modifier_state","content":"pub fn get_modifier_state(\n  event: KeyboardEvent,\n  key: String,\n) -&gt; Bool\n [Documentation](https://developer.mozilla.org/docs/Web/API/KeyboardEvent/getModifierState)\nSynonyms:\nredraw/dom/event/keyboard.get_modifier_state\nredraw/dom/event/keyboard get_modifier_state","url":"redraw/dom/event/keyboard.html#get_modifier_state"},{"doc":"redraw/dom/event/keyboard","title":"key","content":"pub fn key(event: KeyboardEvent) -&gt; String\n [Documentation](https://developer.mozilla.org/docs/Web/API/KeyboardEvent/key)\nSynonyms:\nredraw/dom/event/keyboard.key\nredraw/dom/event/keyboard key","url":"redraw/dom/event/keyboard.html#key"},{"doc":"redraw/dom/event/keyboard","title":"locale","content":"pub fn locale(event: KeyboardEvent) -&gt; String\n [Documentation](https://developer.mozilla.org/docs/Web/API/KeyboardEvent/locale)\nSynonyms:\nredraw/dom/event/keyboard.locale\nredraw/dom/event/keyboard locale","url":"redraw/dom/event/keyboard.html#locale"},{"doc":"redraw/dom/event/keyboard","title":"location","content":"pub fn location(event: KeyboardEvent) -&gt; Float\n [Documentation](https://developer.mozilla.org/docs/Web/API/KeyboardEvent/location)\nSynonyms:\nredraw/dom/event/keyboard.location\nredraw/dom/event/keyboard location","url":"redraw/dom/event/keyboard.html#location"},{"doc":"redraw/dom/event/keyboard","title":"meta_key","content":"pub fn meta_key(event: KeyboardEvent) -&gt; Bool\n [Documentation](https://developer.mozilla.org/docs/Web/API/KeyboardEvent/metaKey)\nSynonyms:\nredraw/dom/event/keyboard.meta_key\nredraw/dom/event/keyboard meta_key","url":"redraw/dom/event/keyboard.html#meta_key"},{"doc":"redraw/dom/event/keyboard","title":"repeat","content":"pub fn repeat(event: KeyboardEvent) -&gt; Bool\n [Documentation](https://developer.mozilla.org/docs/Web/API/KeyboardEvent/repeat)\nSynonyms:\nredraw/dom/event/keyboard.repeat\nredraw/dom/event/keyboard repeat","url":"redraw/dom/event/keyboard.html#repeat"},{"doc":"redraw/dom/event/keyboard","title":"shift_key","content":"pub fn shift_key(event: KeyboardEvent) -&gt; Bool\n [Documentation](https://developer.mozilla.org/docs/Web/API/KeyboardEvent/shiftKey)\nSynonyms:\nredraw/dom/event/keyboard.shift_key\nredraw/dom/event/keyboard shift_key","url":"redraw/dom/event/keyboard.html#shift_key"},{"doc":"redraw/dom/event/keyboard","title":"redraw/dom/event/keyboard","content":" `KeyboardEvent` objects describe a user interaction with the keyboard; each\n event describes a single interaction between the user and a key (or\n combination of a key with modifier keys) on the keyboard. The event type\n ([`keydown`](https://developer.mozilla.org/docs/Web/API/Element/keydown_event),\n [`keypress`](https://developer.mozilla.org/docs/Web/API/Element/keypress_event),\n or [`keyup`](https://developer.mozilla.org/docs/Web/API/Element/keyup_event))\n identifies what kind of keyboard activity occurred.","url":"redraw/dom/event/keyboard.html"},{"doc":"redraw/dom/event/pointer","title":"PointerEvent","content":"pub type PointerEvent\n [Documentation](https://developer.mozilla.org/docs/Web/API/PointerEvent)\n\nSynonyms:\nredraw/dom/event/pointer.PointerEvent\nredraw/dom/event/pointer PointerEvent","url":"redraw/dom/event/pointer.html#PointerEvent"},{"doc":"redraw/dom/event/pointer","title":"altitude_angle","content":"pub fn altitude_angle(event: PointerEvent) -&gt; Int\n [Documentation](https://developer.mozilla.org/docs/Web/API/PointerEvent/altitudeAngle)\nSynonyms:\nredraw/dom/event/pointer.altitude_angle\nredraw/dom/event/pointer altitude_angle","url":"redraw/dom/event/pointer.html#altitude_angle"},{"doc":"redraw/dom/event/pointer","title":"as_event","content":"pub fn as_event(event: PointerEvent) -&gt; Event\n `PointerEvent` inherits `Event`.\nSynonyms:\nredraw/dom/event/pointer.as_event\nredraw/dom/event/pointer as_event","url":"redraw/dom/event/pointer.html#as_event"},{"doc":"redraw/dom/event/pointer","title":"as_mouse_event","content":"pub fn as_mouse_event(event: PointerEvent) -&gt; MouseEvent\n `PointerEvent` inherits `MouseEvent`.\nSynonyms:\nredraw/dom/event/pointer.as_mouse_event\nredraw/dom/event/pointer as_mouse_event","url":"redraw/dom/event/pointer.html#as_mouse_event"},{"doc":"redraw/dom/event/pointer","title":"as_ui_event","content":"pub fn as_ui_event(event: PointerEvent) -&gt; UIEvent\n `PointerEvent` inherits `UIEvent`.\nSynonyms:\nredraw/dom/event/pointer.as_ui_event\nredraw/dom/event/pointer as_ui_event","url":"redraw/dom/event/pointer.html#as_ui_event"},{"doc":"redraw/dom/event/pointer","title":"azimuth_angle","content":"pub fn azimuth_angle(event: PointerEvent) -&gt; Int\n [Documentation](https://developer.mozilla.org/docs/Web/API/PointerEvent/azimuthAngle)\nSynonyms:\nredraw/dom/event/pointer.azimuth_angle\nredraw/dom/event/pointer azimuth_angle","url":"redraw/dom/event/pointer.html#azimuth_angle"},{"doc":"redraw/dom/event/pointer","title":"height","content":"pub fn height(event: PointerEvent) -&gt; Int\n [Documentation](https://developer.mozilla.org/docs/Web/API/PointerEvent/height)\nSynonyms:\nredraw/dom/event/pointer.height\nredraw/dom/event/pointer height","url":"redraw/dom/event/pointer.html#height"},{"doc":"redraw/dom/event/pointer","title":"is_primary","content":"pub fn is_primary(event: PointerEvent) -&gt; Bool\n [Documentation](https://developer.mozilla.org/docs/Web/API/PointerEvent/isPrimary)\nSynonyms:\nredraw/dom/event/pointer.is_primary\nredraw/dom/event/pointer is_primary","url":"redraw/dom/event/pointer.html#is_primary"},{"doc":"redraw/dom/event/pointer","title":"pointer_id","content":"pub fn pointer_id(event: PointerEvent) -&gt; Int\n [Documentation](https://developer.mozilla.org/docs/Web/API/PointerEvent/pointerId)\nSynonyms:\nredraw/dom/event/pointer.pointer_id\nredraw/dom/event/pointer pointer_id","url":"redraw/dom/event/pointer.html#pointer_id"},{"doc":"redraw/dom/event/pointer","title":"pointer_type","content":"pub fn pointer_type(event: PointerEvent) -&gt; String\n [Documentation](https://developer.mozilla.org/docs/Web/API/PointerEvent/pointerType)\nSynonyms:\nredraw/dom/event/pointer.pointer_type\nredraw/dom/event/pointer pointer_type","url":"redraw/dom/event/pointer.html#pointer_type"},{"doc":"redraw/dom/event/pointer","title":"pressure","content":"pub fn pressure(event: PointerEvent) -&gt; Float\n [Documentation](https://developer.mozilla.org/docs/Web/API/PointerEvent/pressure)\nSynonyms:\nredraw/dom/event/pointer.pressure\nredraw/dom/event/pointer pressure","url":"redraw/dom/event/pointer.html#pressure"},{"doc":"redraw/dom/event/pointer","title":"tangential_pressure","content":"pub fn tangential_pressure(event: PointerEvent) -&gt; Float\n [Documentation](https://developer.mozilla.org/docs/Web/API/PointerEvent/tangentialPressure)\nSynonyms:\nredraw/dom/event/pointer.tangential_pressure\nredraw/dom/event/pointer tangential_pressure","url":"redraw/dom/event/pointer.html#tangential_pressure"},{"doc":"redraw/dom/event/pointer","title":"tilt_x","content":"pub fn tilt_x(event: PointerEvent) -&gt; Int\n [Documentation](https://developer.mozilla.org/docs/Web/API/PointerEvent/tiltX)\nSynonyms:\nredraw/dom/event/pointer.tilt_x\nredraw/dom/event/pointer tilt_x","url":"redraw/dom/event/pointer.html#tilt_x"},{"doc":"redraw/dom/event/pointer","title":"tilt_y","content":"pub fn tilt_y(event: PointerEvent) -&gt; Int\n [Documentation](https://developer.mozilla.org/docs/Web/API/PointerEvent/tiltY)\nSynonyms:\nredraw/dom/event/pointer.tilt_y\nredraw/dom/event/pointer tilt_y","url":"redraw/dom/event/pointer.html#tilt_y"},{"doc":"redraw/dom/event/pointer","title":"twist","content":"pub fn twist(event: PointerEvent) -&gt; Int\n [Documentation](https://developer.mozilla.org/docs/Web/API/PointerEvent/twist)\nSynonyms:\nredraw/dom/event/pointer.twist\nredraw/dom/event/pointer twist","url":"redraw/dom/event/pointer.html#twist"},{"doc":"redraw/dom/event/pointer","title":"width","content":"pub fn width(event: PointerEvent) -&gt; Int\n [Documentation](https://developer.mozilla.org/docs/Web/API/PointerEvent/width)\nSynonyms:\nredraw/dom/event/pointer.width\nredraw/dom/event/pointer width","url":"redraw/dom/event/pointer.html#width"},{"doc":"redraw/dom/event/pointer","title":"redraw/dom/event/pointer","content":" The `PointerEvent` interface represents the state of a DOM event produced by\n a pointer such as the geometry of the contact point, the device type that\n generated the event, the amount of pressure that was applied on the contact\n surface, etc.\n\n A pointer is a hardware agnostic representation of input devices (such as a\n mouse, pen or contact point on a touch-enable surface). The pointer can\n target a specific coordinate (or set of coordinates) on the contact surface\n such as a screen.\n\n A pointer&#39;s hit test is the process a browser uses to determine the target\n element for a pointer event. Typically, this is determined by considering\n the pointer&#39;s location and also the visual layout of elements in a document\n on screen media.","url":"redraw/dom/event/pointer.html"},{"doc":"redraw/dom/event/touch","title":"TouchEvent","content":"pub type TouchEvent\n [Documentation](https://developer.mozilla.org/docs/Web/API/TouchEvent)\n\nSynonyms:\nredraw/dom/event/touch.TouchEvent\nredraw/dom/event/touch TouchEvent","url":"redraw/dom/event/touch.html#TouchEvent"},{"doc":"redraw/dom/event/touch","title":"alt_key","content":"pub fn alt_key(event: TouchEvent) -&gt; Bool\n [Documentation](https://developer.mozilla.org/docs/Web/API/TouchEvent/altKey)\nSynonyms:\nredraw/dom/event/touch.alt_key\nredraw/dom/event/touch alt_key","url":"redraw/dom/event/touch.html#alt_key"},{"doc":"redraw/dom/event/touch","title":"as_event","content":"pub fn as_event(event: TouchEvent) -&gt; Event\n `TouchEvent` inherits `Event`.\nSynonyms:\nredraw/dom/event/touch.as_event\nredraw/dom/event/touch as_event","url":"redraw/dom/event/touch.html#as_event"},{"doc":"redraw/dom/event/touch","title":"as_ui_event","content":"pub fn as_ui_event(event: TouchEvent) -&gt; UIEvent\n `TouchEvent` inherits `UIEvent`.\nSynonyms:\nredraw/dom/event/touch.as_ui_event\nredraw/dom/event/touch as_ui_event","url":"redraw/dom/event/touch.html#as_ui_event"},{"doc":"redraw/dom/event/touch","title":"changed_touches","content":"pub fn changed_touches(event: TouchEvent) -&gt; Dynamic\n [Documentation](https://developer.mozilla.org/docs/Web/API/TouchEvent/changedTouches)\nSynonyms:\nredraw/dom/event/touch.changed_touches\nredraw/dom/event/touch changed_touches","url":"redraw/dom/event/touch.html#changed_touches"},{"doc":"redraw/dom/event/touch","title":"ctrl_key","content":"pub fn ctrl_key(event: TouchEvent) -&gt; Bool\n [Documentation](https://developer.mozilla.org/docs/Web/API/TouchEvent/ctrlKey)\nSynonyms:\nredraw/dom/event/touch.ctrl_key\nredraw/dom/event/touch ctrl_key","url":"redraw/dom/event/touch.html#ctrl_key"},{"doc":"redraw/dom/event/touch","title":"get_modifier_state","content":"pub fn get_modifier_state(event: TouchEvent, key: String) -&gt; Bool\n [Documentation](https://developer.mozilla.org/docs/Web/API/TouchEvent/getModifierState)\nSynonyms:\nredraw/dom/event/touch.get_modifier_state\nredraw/dom/event/touch get_modifier_state","url":"redraw/dom/event/touch.html#get_modifier_state"},{"doc":"redraw/dom/event/touch","title":"meta_key","content":"pub fn meta_key(event: TouchEvent) -&gt; Bool\n [Documentation](https://developer.mozilla.org/docs/Web/API/TouchEvent/metaKey)\nSynonyms:\nredraw/dom/event/touch.meta_key\nredraw/dom/event/touch meta_key","url":"redraw/dom/event/touch.html#meta_key"},{"doc":"redraw/dom/event/touch","title":"shift_key","content":"pub fn shift_key(event: TouchEvent) -&gt; Bool\n [Documentation](https://developer.mozilla.org/docs/Web/API/TouchEvent/shiftKey)\nSynonyms:\nredraw/dom/event/touch.shift_key\nredraw/dom/event/touch shift_key","url":"redraw/dom/event/touch.html#shift_key"},{"doc":"redraw/dom/event/touch","title":"target_touches","content":"pub fn target_touches(event: TouchEvent) -&gt; Dynamic\n [Documentation](https://developer.mozilla.org/docs/Web/API/TouchEvent/targetTouches)\nSynonyms:\nredraw/dom/event/touch.target_touches\nredraw/dom/event/touch target_touches","url":"redraw/dom/event/touch.html#target_touches"},{"doc":"redraw/dom/event/touch","title":"touches","content":"pub fn touches(event: TouchEvent) -&gt; Dynamic\n [Documentation](https://developer.mozilla.org/docs/Web/API/TouchEvent/touches)\nSynonyms:\nredraw/dom/event/touch.touches\nredraw/dom/event/touch touches","url":"redraw/dom/event/touch.html#touches"},{"doc":"redraw/dom/event/touch","title":"redraw/dom/event/touch","content":" To provide quality support for touch-based user interfaces, touch events\n offer the ability to interpret finger (or stylus) activity on touch screens\n or trackpads.\n\n The touch events interfaces are relatively low-level APIs that can be used\n to support application-specific multi-touch interactions such as a\n two-finger gesture. A multi-touch interaction starts when a finger (or\n stylus) first touches the contact surface. Other fingers may subsequently\n touch the surface and optionally move across the touch surface. The\n interaction ends when the fingers are removed from the surface. During this\n interaction, an application receives touch events during the start, move,\n and end phases.\n\n Touch events are similar to mouse events except they support simultaneous\n touches and at different locations on the touch surface. The `TouchEvent`\n interface encapsulates all of the touchpoints that are currently active.\n The [`Touch`](https://developer.mozilla.org/docs/Web/API/Touch)\n interface, which represents a single touchpoint, includes information such\n as the position of the touch point relative to the browser viewport.\n\n [Documentation](https://developer.mozilla.org/docs/Web/API/Touch_events)","url":"redraw/dom/event/touch.html"},{"doc":"redraw/dom/event/transition","title":"TransitionEvent","content":"pub type TransitionEvent\n [Documentation](https://developer.mozilla.org/docs/Web/API/TransitionEvent)\n\nSynonyms:\nredraw/dom/event/transition.TransitionEvent\nredraw/dom/event/transition TransitionEvent","url":"redraw/dom/event/transition.html#TransitionEvent"},{"doc":"redraw/dom/event/transition","title":"as_event","content":"pub fn as_event(event: TransitionEvent) -&gt; Event\n `TransitionEvent` inherits `Event`.\nSynonyms:\nredraw/dom/event/transition.as_event\nredraw/dom/event/transition as_event","url":"redraw/dom/event/transition.html#as_event"},{"doc":"redraw/dom/event/transition","title":"elapsed_time","content":"pub fn elapsed_time(event: TransitionEvent) -&gt; Int\n [Documentation](https://developer.mozilla.org/docs/Web/API/TransitionEvent/elapsedTime)\nSynonyms:\nredraw/dom/event/transition.elapsed_time\nredraw/dom/event/transition elapsed_time","url":"redraw/dom/event/transition.html#elapsed_time"},{"doc":"redraw/dom/event/transition","title":"property_name","content":"pub fn property_name(event: TransitionEvent) -&gt; String\n [Documentation](https://developer.mozilla.org/docs/Web/API/TransitionEvent/propertyName)\nSynonyms:\nredraw/dom/event/transition.property_name\nredraw/dom/event/transition property_name","url":"redraw/dom/event/transition.html#property_name"},{"doc":"redraw/dom/event/transition","title":"pseudo_element","content":"pub fn pseudo_element(event: TransitionEvent) -&gt; String\n [Documentation](https://developer.mozilla.org/docs/Web/API/TransitionEvent/pseudoElement)\nSynonyms:\nredraw/dom/event/transition.pseudo_element\nredraw/dom/event/transition pseudo_element","url":"redraw/dom/event/transition.html#pseudo_element"},{"doc":"redraw/dom/event/transition","title":"redraw/dom/event/transition","content":" The `TransitionEvent` interface represents events providing information\n related to [transitions](https://developer.mozilla.org/docs/Web/CSS/CSS_transitions/Using_CSS_transitions).","url":"redraw/dom/event/transition.html"},{"doc":"redraw/dom/event/wheel","title":"WheelEvent","content":"pub type WheelEvent\n [Documentation](https://developer.mozilla.org/docs/Web/API/WheelEvent)\n\nSynonyms:\nredraw/dom/event/wheel.WheelEvent\nredraw/dom/event/wheel WheelEvent","url":"redraw/dom/event/wheel.html#WheelEvent"},{"doc":"redraw/dom/event/wheel","title":"as_event","content":"pub fn as_event(event: WheelEvent) -&gt; Event\n `WheelEvent` inherits `Event`.\nSynonyms:\nredraw/dom/event/wheel.as_event\nredraw/dom/event/wheel as_event","url":"redraw/dom/event/wheel.html#as_event"},{"doc":"redraw/dom/event/wheel","title":"as_mouse_event","content":"pub fn as_mouse_event(event: WheelEvent) -&gt; MouseEvent\n `WheelEvent` inherits `MouseEvent`.\nSynonyms:\nredraw/dom/event/wheel.as_mouse_event\nredraw/dom/event/wheel as_mouse_event","url":"redraw/dom/event/wheel.html#as_mouse_event"},{"doc":"redraw/dom/event/wheel","title":"as_ui_event","content":"pub fn as_ui_event(event: WheelEvent) -&gt; UIEvent\n `WheelEvent` inherits `UIEvent`.\nSynonyms:\nredraw/dom/event/wheel.as_ui_event\nredraw/dom/event/wheel as_ui_event","url":"redraw/dom/event/wheel.html#as_ui_event"},{"doc":"redraw/dom/event/wheel","title":"delta_mode","content":"pub fn delta_mode(event: WheelEvent) -&gt; Int\n [Documentation](https://developer.mozilla.org/docs/Web/API/WheelEvent/deltaMode)\nSynonyms:\nredraw/dom/event/wheel.delta_mode\nredraw/dom/event/wheel delta_mode","url":"redraw/dom/event/wheel.html#delta_mode"},{"doc":"redraw/dom/event/wheel","title":"delta_x","content":"pub fn delta_x(event: WheelEvent) -&gt; Float\n [Documentation](https://developer.mozilla.org/docs/Web/API/WheelEvent/deltaX)\nSynonyms:\nredraw/dom/event/wheel.delta_x\nredraw/dom/event/wheel delta_x","url":"redraw/dom/event/wheel.html#delta_x"},{"doc":"redraw/dom/event/wheel","title":"delta_y","content":"pub fn delta_y(event: WheelEvent) -&gt; Float\n [Documentation](https://developer.mozilla.org/docs/Web/API/WheelEvent/deltaY)\nSynonyms:\nredraw/dom/event/wheel.delta_y\nredraw/dom/event/wheel delta_y","url":"redraw/dom/event/wheel.html#delta_y"},{"doc":"redraw/dom/event/wheel","title":"delta_z","content":"pub fn delta_z(event: WheelEvent) -&gt; Float\n [Documentation](https://developer.mozilla.org/docs/Web/API/WheelEvent/deltaZ)\nSynonyms:\nredraw/dom/event/wheel.delta_z\nredraw/dom/event/wheel delta_z","url":"redraw/dom/event/wheel.html#delta_z"},{"doc":"redraw/dom/event/wheel","title":"redraw/dom/event/wheel","content":" The `WheelEvent` interface represents events that occur due to the user\n moving a mouse wheel or similar input device.\n\n &gt; This is the standard wheel event interface to use. Old versions\n of browsers implemented the non-standard and non-cross-browser-compatible\n `MouseWheelEvent` and `MouseScrollEvent` interfaces. Use this interface and\n avoid the non-standard ones.\n\n Don&#39;t confuse the wheel event with the [`scroll`](https://developer.mozilla.org/docs/Web/API/Element/scroll_event) event:\n - A `wheel` event doesn&#39;t necessarily dispatch a `scroll` event. For example,\n   the element may be unscrollable at all. Zooming actions using the wheel\n   or trackpad also fire `wheel` events.\n - A `scroll` event isn&#39;t necessarily triggered by a `wheel` event. Elements\n   can also be scrolled by using the keyboard, dragging a scrollbar, or\n   using JavaScript.\n - Even when the `wheel` event does trigger scrolling, the `delta*` values in\n   the `wheel` event don&#39;t necessarily reflect the content&#39;s scrolling\n   direction.","url":"redraw/dom/event/wheel.html"},{"doc":"redraw/dom/events","title":"on_abort","content":"pub fn on_abort(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/abort_event)\nSynonyms:\nredraw/dom/events.on_abort\nredraw/dom/events on_abort","url":"redraw/dom/events.html#on_abort"},{"doc":"redraw/dom/events","title":"on_abort_capture","content":"pub fn on_abort_capture(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n Alternative version of [`on_abort`](#on_abort) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/abort_event)\nSynonyms:\nredraw/dom/events.on_abort_capture\nredraw/dom/events on_abort_capture","url":"redraw/dom/events.html#on_abort_capture"},{"doc":"redraw/dom/events","title":"on_animation_end","content":"pub fn on_animation_end(\n  handler: fn(AnimationEvent) -&gt; Nil,\n) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/animationend_event)\nSynonyms:\nredraw/dom/events.on_animation_end\nredraw/dom/events on_animation_end","url":"redraw/dom/events.html#on_animation_end"},{"doc":"redraw/dom/events","title":"on_animation_end_capture","content":"pub fn on_animation_end_capture(\n  handler: fn(AnimationEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_animation_end`](#on_animation_end) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/animationend_event)\nSynonyms:\nredraw/dom/events.on_animation_end_capture\nredraw/dom/events on_animation_end_capture","url":"redraw/dom/events.html#on_animation_end_capture"},{"doc":"redraw/dom/events","title":"on_animation_iteration","content":"pub fn on_animation_iteration(\n  handler: fn(AnimationEvent) -&gt; Nil,\n) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/animationiteration_event)\nSynonyms:\nredraw/dom/events.on_animation_iteration\nredraw/dom/events on_animation_iteration","url":"redraw/dom/events.html#on_animation_iteration"},{"doc":"redraw/dom/events","title":"on_animation_iteration_capture","content":"pub fn on_animation_iteration_capture(\n  handler: fn(AnimationEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_animation_iteration`](#on_animation_iteration) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/animationiteration_event)\nSynonyms:\nredraw/dom/events.on_animation_iteration_capture\nredraw/dom/events on_animation_iteration_capture","url":"redraw/dom/events.html#on_animation_iteration_capture"},{"doc":"redraw/dom/events","title":"on_animation_start","content":"pub fn on_animation_start(\n  handler: fn(AnimationEvent) -&gt; Nil,\n) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/animationstart_event)\nSynonyms:\nredraw/dom/events.on_animation_start\nredraw/dom/events on_animation_start","url":"redraw/dom/events.html#on_animation_start"},{"doc":"redraw/dom/events","title":"on_animation_start_capture","content":"pub fn on_animation_start_capture(\n  handler: fn(AnimationEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_animation_start`](#on_animation_start) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/animationstart_event)\nSynonyms:\nredraw/dom/events.on_animation_start_capture\nredraw/dom/events on_animation_start_capture","url":"redraw/dom/events.html#on_animation_start_capture"},{"doc":"redraw/dom/events","title":"on_aux_click","content":"pub fn on_aux_click(handler: fn(MouseEvent) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/auxclick_event)\nSynonyms:\nredraw/dom/events.on_aux_click\nredraw/dom/events on_aux_click","url":"redraw/dom/events.html#on_aux_click"},{"doc":"redraw/dom/events","title":"on_aux_click_capture","content":"pub fn on_aux_click_capture(\n  handler: fn(MouseEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_aux_click`](#on_aux_click) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/auxclick_event)\nSynonyms:\nredraw/dom/events.on_aux_click_capture\nredraw/dom/events on_aux_click_capture","url":"redraw/dom/events.html#on_aux_click_capture"},{"doc":"redraw/dom/events","title":"on_before_input","content":"pub fn on_before_input(\n  handler: fn(InputEvent) -&gt; Nil,\n) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/beforeinput_event)\nSynonyms:\nredraw/dom/events.on_before_input\nredraw/dom/events on_before_input","url":"redraw/dom/events.html#on_before_input"},{"doc":"redraw/dom/events","title":"on_before_input_capture","content":"pub fn on_before_input_capture(\n  handler: fn(InputEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_before_input`](#on_before_input) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/beforeinput_event)\nSynonyms:\nredraw/dom/events.on_before_input_capture\nredraw/dom/events on_before_input_capture","url":"redraw/dom/events.html#on_before_input_capture"},{"doc":"redraw/dom/events","title":"on_blur","content":"pub fn on_blur(handler: fn(FocusEvent) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/blur_event)\nSynonyms:\nredraw/dom/events.on_blur\nredraw/dom/events on_blur","url":"redraw/dom/events.html#on_blur"},{"doc":"redraw/dom/events","title":"on_blur_capture","content":"pub fn on_blur_capture(\n  handler: fn(FocusEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_blur`](#on_blur) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/blur_event)\nSynonyms:\nredraw/dom/events.on_blur_capture\nredraw/dom/events on_blur_capture","url":"redraw/dom/events.html#on_blur_capture"},{"doc":"redraw/dom/events","title":"on_can_play","content":"pub fn on_can_play(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/canplay_event)\nSynonyms:\nredraw/dom/events.on_can_play\nredraw/dom/events on_can_play","url":"redraw/dom/events.html#on_can_play"},{"doc":"redraw/dom/events","title":"on_can_play_capture","content":"pub fn on_can_play_capture(\n  handler: fn(Event) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_can_play`](#on_can_play) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/canplay_event)\nSynonyms:\nredraw/dom/events.on_can_play_capture\nredraw/dom/events on_can_play_capture","url":"redraw/dom/events.html#on_can_play_capture"},{"doc":"redraw/dom/events","title":"on_can_play_through","content":"pub fn on_can_play_through(\n  handler: fn(Event) -&gt; Nil,\n) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/canplaythrough_event)\nSynonyms:\nredraw/dom/events.on_can_play_through\nredraw/dom/events on_can_play_through","url":"redraw/dom/events.html#on_can_play_through"},{"doc":"redraw/dom/events","title":"on_can_play_through_capture","content":"pub fn on_can_play_through_capture(\n  handler: fn(Event) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_can_play_through`](#on_can_play_through) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/canplaythrough_event)\nSynonyms:\nredraw/dom/events.on_can_play_through_capture\nredraw/dom/events on_can_play_through_capture","url":"redraw/dom/events.html#on_can_play_through_capture"},{"doc":"redraw/dom/events","title":"on_cancel","content":"pub fn on_cancel(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/cancel_event)\nSynonyms:\nredraw/dom/events.on_cancel\nredraw/dom/events on_cancel","url":"redraw/dom/events.html#on_cancel"},{"doc":"redraw/dom/events","title":"on_cancel_capture","content":"pub fn on_cancel_capture(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n Alternative version of [`on_cancel`](#on_cancel) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/cancel_event)\nSynonyms:\nredraw/dom/events.on_cancel_capture\nredraw/dom/events on_cancel_capture","url":"redraw/dom/events.html#on_cancel_capture"},{"doc":"redraw/dom/events","title":"on_click","content":"pub fn on_click(handler: fn(MouseEvent) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/click_event)\nSynonyms:\nredraw/dom/events.on_click\nredraw/dom/events on_click","url":"redraw/dom/events.html#on_click"},{"doc":"redraw/dom/events","title":"on_click_capture","content":"pub fn on_click_capture(\n  handler: fn(MouseEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_click`](#on_click) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/click_event)\nSynonyms:\nredraw/dom/events.on_click_capture\nredraw/dom/events on_click_capture","url":"redraw/dom/events.html#on_click_capture"},{"doc":"redraw/dom/events","title":"on_close","content":"pub fn on_close(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/close_event)\nSynonyms:\nredraw/dom/events.on_close\nredraw/dom/events on_close","url":"redraw/dom/events.html#on_close"},{"doc":"redraw/dom/events","title":"on_close_capture","content":"pub fn on_close_capture(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n Alternative version of [`on_close`](#on_close) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/close_event)\nSynonyms:\nredraw/dom/events.on_close_capture\nredraw/dom/events on_close_capture","url":"redraw/dom/events.html#on_close_capture"},{"doc":"redraw/dom/events","title":"on_composition_end","content":"pub fn on_composition_end(\n  handler: fn(CompositionEvent) -&gt; Nil,\n) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/compositionend_event)\nSynonyms:\nredraw/dom/events.on_composition_end\nredraw/dom/events on_composition_end","url":"redraw/dom/events.html#on_composition_end"},{"doc":"redraw/dom/events","title":"on_composition_end_capture","content":"pub fn on_composition_end_capture(\n  handler: fn(CompositionEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_composition_end`](#on_composition_end) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/compositionend_event)\nSynonyms:\nredraw/dom/events.on_composition_end_capture\nredraw/dom/events on_composition_end_capture","url":"redraw/dom/events.html#on_composition_end_capture"},{"doc":"redraw/dom/events","title":"on_composition_start","content":"pub fn on_composition_start(\n  handler: fn(CompositionEvent) -&gt; Nil,\n) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/compositionstart_event)\nSynonyms:\nredraw/dom/events.on_composition_start\nredraw/dom/events on_composition_start","url":"redraw/dom/events.html#on_composition_start"},{"doc":"redraw/dom/events","title":"on_composition_start_capture","content":"pub fn on_composition_start_capture(\n  handler: fn(CompositionEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_composition_start`](#on_composition_start) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/compositionstart_event)\nSynonyms:\nredraw/dom/events.on_composition_start_capture\nredraw/dom/events on_composition_start_capture","url":"redraw/dom/events.html#on_composition_start_capture"},{"doc":"redraw/dom/events","title":"on_composition_update","content":"pub fn on_composition_update(\n  handler: fn(CompositionEvent) -&gt; Nil,\n) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/compositionupdate_event)\nSynonyms:\nredraw/dom/events.on_composition_update\nredraw/dom/events on_composition_update","url":"redraw/dom/events.html#on_composition_update"},{"doc":"redraw/dom/events","title":"on_composition_update_capture","content":"pub fn on_composition_update_capture(\n  handler: fn(CompositionEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_composition_update`](#on_composition_update) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/compositionupdate_event)\nSynonyms:\nredraw/dom/events.on_composition_update_capture\nredraw/dom/events on_composition_update_capture","url":"redraw/dom/events.html#on_composition_update_capture"},{"doc":"redraw/dom/events","title":"on_context_menu","content":"pub fn on_context_menu(\n  handler: fn(MouseEvent) -&gt; Nil,\n) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/context_event)\nSynonyms:\nredraw/dom/events.on_context_menu\nredraw/dom/events on_context_menu","url":"redraw/dom/events.html#on_context_menu"},{"doc":"redraw/dom/events","title":"on_context_menu_capture","content":"pub fn on_context_menu_capture(\n  handler: fn(MouseEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_context_menu`](#on_context_menu) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/context_event)\nSynonyms:\nredraw/dom/events.on_context_menu_capture\nredraw/dom/events on_context_menu_capture","url":"redraw/dom/events.html#on_context_menu_capture"},{"doc":"redraw/dom/events","title":"on_copy","content":"pub fn on_copy(handler: fn(ClipboardEvent) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/copy_event)\nSynonyms:\nredraw/dom/events.on_copy\nredraw/dom/events on_copy","url":"redraw/dom/events.html#on_copy"},{"doc":"redraw/dom/events","title":"on_copy_capture","content":"pub fn on_copy_capture(\n  handler: fn(ClipboardEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_copy`](#on_copy) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/copy_event)\nSynonyms:\nredraw/dom/events.on_copy_capture\nredraw/dom/events on_copy_capture","url":"redraw/dom/events.html#on_copy_capture"},{"doc":"redraw/dom/events","title":"on_cut","content":"pub fn on_cut(handler: fn(ClipboardEvent) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/cut_event)\nSynonyms:\nredraw/dom/events.on_cut\nredraw/dom/events on_cut","url":"redraw/dom/events.html#on_cut"},{"doc":"redraw/dom/events","title":"on_cut_capture","content":"pub fn on_cut_capture(\n  handler: fn(ClipboardEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_cut`](#on_cut) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/cut_event)\nSynonyms:\nredraw/dom/events.on_cut_capture\nredraw/dom/events on_cut_capture","url":"redraw/dom/events.html#on_cut_capture"},{"doc":"redraw/dom/events","title":"on_double_click","content":"pub fn on_double_click(\n  handler: fn(MouseEvent) -&gt; Nil,\n) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/dblclick_event)\nSynonyms:\nredraw/dom/events.on_double_click\nredraw/dom/events on_double_click","url":"redraw/dom/events.html#on_double_click"},{"doc":"redraw/dom/events","title":"on_double_click_capture","content":"pub fn on_double_click_capture(\n  handler: fn(MouseEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_double_click`](#on_double_click) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/dblclick_event)\nSynonyms:\nredraw/dom/events.on_double_click_capture\nredraw/dom/events on_double_click_capture","url":"redraw/dom/events.html#on_double_click_capture"},{"doc":"redraw/dom/events","title":"on_drag","content":"pub fn on_drag(handler: fn(DragEvent) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/drag_event)\nSynonyms:\nredraw/dom/events.on_drag\nredraw/dom/events on_drag","url":"redraw/dom/events.html#on_drag"},{"doc":"redraw/dom/events","title":"on_drag_capture","content":"pub fn on_drag_capture(\n  handler: fn(DragEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_drag`](#on_drag) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/drag_event)\nSynonyms:\nredraw/dom/events.on_drag_capture\nredraw/dom/events on_drag_capture","url":"redraw/dom/events.html#on_drag_capture"},{"doc":"redraw/dom/events","title":"on_drag_end","content":"pub fn on_drag_end(handler: fn(DragEvent) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/dragend_event)\nSynonyms:\nredraw/dom/events.on_drag_end\nredraw/dom/events on_drag_end","url":"redraw/dom/events.html#on_drag_end"},{"doc":"redraw/dom/events","title":"on_drag_end_capture","content":"pub fn on_drag_end_capture(\n  handler: fn(DragEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_drag_end`](#on_drag_end) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/dragend_event)\nSynonyms:\nredraw/dom/events.on_drag_end_capture\nredraw/dom/events on_drag_end_capture","url":"redraw/dom/events.html#on_drag_end_capture"},{"doc":"redraw/dom/events","title":"on_drag_enter","content":"pub fn on_drag_enter(handler: fn(DragEvent) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/dragenter_event)\nSynonyms:\nredraw/dom/events.on_drag_enter\nredraw/dom/events on_drag_enter","url":"redraw/dom/events.html#on_drag_enter"},{"doc":"redraw/dom/events","title":"on_drag_enter_capture","content":"pub fn on_drag_enter_capture(\n  handler: fn(DragEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_drag_enter`](#on_drag_enter) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/dragenter_event)\nSynonyms:\nredraw/dom/events.on_drag_enter_capture\nredraw/dom/events on_drag_enter_capture","url":"redraw/dom/events.html#on_drag_enter_capture"},{"doc":"redraw/dom/events","title":"on_drag_over","content":"pub fn on_drag_over(handler: fn(DragEvent) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/dragover_event)\nSynonyms:\nredraw/dom/events.on_drag_over\nredraw/dom/events on_drag_over","url":"redraw/dom/events.html#on_drag_over"},{"doc":"redraw/dom/events","title":"on_drag_over_capture","content":"pub fn on_drag_over_capture(\n  handler: fn(DragEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_drag_over`](#on_drag_over) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/dragover_event)\nSynonyms:\nredraw/dom/events.on_drag_over_capture\nredraw/dom/events on_drag_over_capture","url":"redraw/dom/events.html#on_drag_over_capture"},{"doc":"redraw/dom/events","title":"on_drag_start","content":"pub fn on_drag_start(handler: fn(DragEvent) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/dragstart_event)\nSynonyms:\nredraw/dom/events.on_drag_start\nredraw/dom/events on_drag_start","url":"redraw/dom/events.html#on_drag_start"},{"doc":"redraw/dom/events","title":"on_drag_start_capture","content":"pub fn on_drag_start_capture(\n  handler: fn(DragEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_drag_start`](#on_drag_start) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/dragstart_event)\nSynonyms:\nredraw/dom/events.on_drag_start_capture\nredraw/dom/events on_drag_start_capture","url":"redraw/dom/events.html#on_drag_start_capture"},{"doc":"redraw/dom/events","title":"on_drop","content":"pub fn on_drop(handler: fn(DragEvent) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/drop_event)\nSynonyms:\nredraw/dom/events.on_drop\nredraw/dom/events on_drop","url":"redraw/dom/events.html#on_drop"},{"doc":"redraw/dom/events","title":"on_drop_capture","content":"pub fn on_drop_capture(\n  handler: fn(DragEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_drop`](#on_drop) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/drop_event)\nSynonyms:\nredraw/dom/events.on_drop_capture\nredraw/dom/events on_drop_capture","url":"redraw/dom/events.html#on_drop_capture"},{"doc":"redraw/dom/events","title":"on_duration_change","content":"pub fn on_duration_change(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/durationchange_event)\nSynonyms:\nredraw/dom/events.on_duration_change\nredraw/dom/events on_duration_change","url":"redraw/dom/events.html#on_duration_change"},{"doc":"redraw/dom/events","title":"on_duration_change_capture","content":"pub fn on_duration_change_capture(\n  handler: fn(Event) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_duration_change`](#on_duration_change) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/durationchange_event)\nSynonyms:\nredraw/dom/events.on_duration_change_capture\nredraw/dom/events on_duration_change_capture","url":"redraw/dom/events.html#on_duration_change_capture"},{"doc":"redraw/dom/events","title":"on_emptied","content":"pub fn on_emptied(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/emptied_event)\nSynonyms:\nredraw/dom/events.on_emptied\nredraw/dom/events on_emptied","url":"redraw/dom/events.html#on_emptied"},{"doc":"redraw/dom/events","title":"on_emptied_capture","content":"pub fn on_emptied_capture(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n Alternative version of [`on_emptied`](#on_emptied) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/emptied_event)\nSynonyms:\nredraw/dom/events.on_emptied_capture\nredraw/dom/events on_emptied_capture","url":"redraw/dom/events.html#on_emptied_capture"},{"doc":"redraw/dom/events","title":"on_encrypted","content":"pub fn on_encrypted(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/encrypted_event)\nSynonyms:\nredraw/dom/events.on_encrypted\nredraw/dom/events on_encrypted","url":"redraw/dom/events.html#on_encrypted"},{"doc":"redraw/dom/events","title":"on_encrypted_capture","content":"pub fn on_encrypted_capture(\n  handler: fn(Event) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_encrypted`](#on_encrypted) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/encrypted_event)\nSynonyms:\nredraw/dom/events.on_encrypted_capture\nredraw/dom/events on_encrypted_capture","url":"redraw/dom/events.html#on_encrypted_capture"},{"doc":"redraw/dom/events","title":"on_ended","content":"pub fn on_ended(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/ended_event)\nSynonyms:\nredraw/dom/events.on_ended\nredraw/dom/events on_ended","url":"redraw/dom/events.html#on_ended"},{"doc":"redraw/dom/events","title":"on_ended_capture","content":"pub fn on_ended_capture(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n Alternative version of [`on_ended`](#on_ended) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/ended_event)\nSynonyms:\nredraw/dom/events.on_ended_capture\nredraw/dom/events on_ended_capture","url":"redraw/dom/events.html#on_ended_capture"},{"doc":"redraw/dom/events","title":"on_error","content":"pub fn on_error(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/error_event)\nSynonyms:\nredraw/dom/events.on_error\nredraw/dom/events on_error","url":"redraw/dom/events.html#on_error"},{"doc":"redraw/dom/events","title":"on_error_capture","content":"pub fn on_error_capture(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n Alternative version of [`on_error`](#on_error) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/error_event)\nSynonyms:\nredraw/dom/events.on_error_capture\nredraw/dom/events on_error_capture","url":"redraw/dom/events.html#on_error_capture"},{"doc":"redraw/dom/events","title":"on_focus","content":"pub fn on_focus(handler: fn(FocusEvent) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/focus_event)\nSynonyms:\nredraw/dom/events.on_focus\nredraw/dom/events on_focus","url":"redraw/dom/events.html#on_focus"},{"doc":"redraw/dom/events","title":"on_focus_capture","content":"pub fn on_focus_capture(\n  handler: fn(FocusEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_focus`](#on_focus) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/focus_event)\nSynonyms:\nredraw/dom/events.on_focus_capture\nredraw/dom/events on_focus_capture","url":"redraw/dom/events.html#on_focus_capture"},{"doc":"redraw/dom/events","title":"on_got_pointer_capture","content":"pub fn on_got_pointer_capture(\n  handler: fn(PointerEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_got_pointer`](#on_got_pointer) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/gotpointercapture_event)\nSynonyms:\nredraw/dom/events.on_got_pointer_capture\nredraw/dom/events on_got_pointer_capture","url":"redraw/dom/events.html#on_got_pointer_capture"},{"doc":"redraw/dom/events","title":"on_got_pointer_capture_capture","content":"pub fn on_got_pointer_capture_capture(\n  handler: fn(PointerEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_got_pointer_capture`](#on_got_pointer_capture) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/gotpointercapture_event)\nSynonyms:\nredraw/dom/events.on_got_pointer_capture_capture\nredraw/dom/events on_got_pointer_capture_capture","url":"redraw/dom/events.html#on_got_pointer_capture_capture"},{"doc":"redraw/dom/events","title":"on_key_down","content":"pub fn on_key_down(\n  handler: fn(KeyboardEvent) -&gt; Nil,\n) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/keydown_event)\nSynonyms:\nredraw/dom/events.on_key_down\nredraw/dom/events on_key_down","url":"redraw/dom/events.html#on_key_down"},{"doc":"redraw/dom/events","title":"on_key_down_capture","content":"pub fn on_key_down_capture(\n  handler: fn(KeyboardEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_key_down`](#on_key_down) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/keydown_event)\nSynonyms:\nredraw/dom/events.on_key_down_capture\nredraw/dom/events on_key_down_capture","url":"redraw/dom/events.html#on_key_down_capture"},{"doc":"redraw/dom/events","title":"on_key_press","content":"pub fn on_key_press(\n  handler: fn(KeyboardEvent) -&gt; Nil,\n) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/keypress_event)\nSynonyms:\nredraw/dom/events.on_key_press\nredraw/dom/events on_key_press","url":"redraw/dom/events.html#on_key_press"},{"doc":"redraw/dom/events","title":"on_key_press_capture","content":"pub fn on_key_press_capture(\n  handler: fn(KeyboardEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_key_press`](#on_key_press) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/keypress_event)\nSynonyms:\nredraw/dom/events.on_key_press_capture\nredraw/dom/events on_key_press_capture","url":"redraw/dom/events.html#on_key_press_capture"},{"doc":"redraw/dom/events","title":"on_key_up","content":"pub fn on_key_up(handler: fn(KeyboardEvent) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/keyup_event)\nSynonyms:\nredraw/dom/events.on_key_up\nredraw/dom/events on_key_up","url":"redraw/dom/events.html#on_key_up"},{"doc":"redraw/dom/events","title":"on_key_up_capture","content":"pub fn on_key_up_capture(\n  handler: fn(KeyboardEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_key_up`](#on_key_up) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/keyup_event)\nSynonyms:\nredraw/dom/events.on_key_up_capture\nredraw/dom/events on_key_up_capture","url":"redraw/dom/events.html#on_key_up_capture"},{"doc":"redraw/dom/events","title":"on_load","content":"pub fn on_load(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/load_event)\nSynonyms:\nredraw/dom/events.on_load\nredraw/dom/events on_load","url":"redraw/dom/events.html#on_load"},{"doc":"redraw/dom/events","title":"on_load_capture","content":"pub fn on_load_capture(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n Alternative version of [`on_load`](#on_load) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/load_event)\nSynonyms:\nredraw/dom/events.on_load_capture\nredraw/dom/events on_load_capture","url":"redraw/dom/events.html#on_load_capture"},{"doc":"redraw/dom/events","title":"on_load_start","content":"pub fn on_load_start(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/loadstart_event)\nSynonyms:\nredraw/dom/events.on_load_start\nredraw/dom/events on_load_start","url":"redraw/dom/events.html#on_load_start"},{"doc":"redraw/dom/events","title":"on_load_start_capture","content":"pub fn on_load_start_capture(\n  handler: fn(Event) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_load_start`](#on_load_start) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/loadstart_event)\nSynonyms:\nredraw/dom/events.on_load_start_capture\nredraw/dom/events on_load_start_capture","url":"redraw/dom/events.html#on_load_start_capture"},{"doc":"redraw/dom/events","title":"on_loaded_data","content":"pub fn on_loaded_data(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/loadeddata_event)\nSynonyms:\nredraw/dom/events.on_loaded_data\nredraw/dom/events on_loaded_data","url":"redraw/dom/events.html#on_loaded_data"},{"doc":"redraw/dom/events","title":"on_loaded_data_capture","content":"pub fn on_loaded_data_capture(\n  handler: fn(Event) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_loaded_data`](#on_loaded_data) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/loadeddata_event)\nSynonyms:\nredraw/dom/events.on_loaded_data_capture\nredraw/dom/events on_loaded_data_capture","url":"redraw/dom/events.html#on_loaded_data_capture"},{"doc":"redraw/dom/events","title":"on_loaded_metadata","content":"pub fn on_loaded_metadata(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/loadedmetadata_event)\nSynonyms:\nredraw/dom/events.on_loaded_metadata\nredraw/dom/events on_loaded_metadata","url":"redraw/dom/events.html#on_loaded_metadata"},{"doc":"redraw/dom/events","title":"on_loaded_metadata_capture","content":"pub fn on_loaded_metadata_capture(\n  handler: fn(Event) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_loaded_metadata`](#on_loaded_metadata) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/loadedmetadata_event)\nSynonyms:\nredraw/dom/events.on_loaded_metadata_capture\nredraw/dom/events on_loaded_metadata_capture","url":"redraw/dom/events.html#on_loaded_metadata_capture"},{"doc":"redraw/dom/events","title":"on_lost_pointer_capture","content":"pub fn on_lost_pointer_capture(\n  handler: fn(PointerEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_lost_pointer`](#on_lost_pointer) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/lostpointercapture_event)\nSynonyms:\nredraw/dom/events.on_lost_pointer_capture\nredraw/dom/events on_lost_pointer_capture","url":"redraw/dom/events.html#on_lost_pointer_capture"},{"doc":"redraw/dom/events","title":"on_lost_pointer_capture_capture","content":"pub fn on_lost_pointer_capture_capture(\n  handler: fn(PointerEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_lost_pointer_capture`](#on_lost_pointer_capture) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/lostpointercapture_event)\nSynonyms:\nredraw/dom/events.on_lost_pointer_capture_capture\nredraw/dom/events on_lost_pointer_capture_capture","url":"redraw/dom/events.html#on_lost_pointer_capture_capture"},{"doc":"redraw/dom/events","title":"on_mouse_down","content":"pub fn on_mouse_down(handler: fn(MouseEvent) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/mousedown_event)\nSynonyms:\nredraw/dom/events.on_mouse_down\nredraw/dom/events on_mouse_down","url":"redraw/dom/events.html#on_mouse_down"},{"doc":"redraw/dom/events","title":"on_mouse_down_capture","content":"pub fn on_mouse_down_capture(\n  handler: fn(MouseEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_mouse_down`](#on_mouse_down) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/mousedown_event)\nSynonyms:\nredraw/dom/events.on_mouse_down_capture\nredraw/dom/events on_mouse_down_capture","url":"redraw/dom/events.html#on_mouse_down_capture"},{"doc":"redraw/dom/events","title":"on_mouse_enter","content":"pub fn on_mouse_enter(\n  handler: fn(MouseEvent) -&gt; Nil,\n) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/mouseenter_event)\nSynonyms:\nredraw/dom/events.on_mouse_enter\nredraw/dom/events on_mouse_enter","url":"redraw/dom/events.html#on_mouse_enter"},{"doc":"redraw/dom/events","title":"on_mouse_leave","content":"pub fn on_mouse_leave(\n  handler: fn(MouseEvent) -&gt; Nil,\n) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/mouseleave_event)\nSynonyms:\nredraw/dom/events.on_mouse_leave\nredraw/dom/events on_mouse_leave","url":"redraw/dom/events.html#on_mouse_leave"},{"doc":"redraw/dom/events","title":"on_mouse_move","content":"pub fn on_mouse_move(handler: fn(MouseEvent) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/mousemove_event)\nSynonyms:\nredraw/dom/events.on_mouse_move\nredraw/dom/events on_mouse_move","url":"redraw/dom/events.html#on_mouse_move"},{"doc":"redraw/dom/events","title":"on_mouse_move_capture","content":"pub fn on_mouse_move_capture(\n  handler: fn(MouseEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_mouse_move`](#on_mouse_move) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/mousemove_event)\nSynonyms:\nredraw/dom/events.on_mouse_move_capture\nredraw/dom/events on_mouse_move_capture","url":"redraw/dom/events.html#on_mouse_move_capture"},{"doc":"redraw/dom/events","title":"on_mouse_out","content":"pub fn on_mouse_out(handler: fn(MouseEvent) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/mouseout_event)\nSynonyms:\nredraw/dom/events.on_mouse_out\nredraw/dom/events on_mouse_out","url":"redraw/dom/events.html#on_mouse_out"},{"doc":"redraw/dom/events","title":"on_mouse_out_capture","content":"pub fn on_mouse_out_capture(\n  handler: fn(MouseEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_mouse_out`](#on_mouse_out) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/mouseout_event)\nSynonyms:\nredraw/dom/events.on_mouse_out_capture\nredraw/dom/events on_mouse_out_capture","url":"redraw/dom/events.html#on_mouse_out_capture"},{"doc":"redraw/dom/events","title":"on_mouse_up","content":"pub fn on_mouse_up(handler: fn(MouseEvent) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/mouseup_event)\nSynonyms:\nredraw/dom/events.on_mouse_up\nredraw/dom/events on_mouse_up","url":"redraw/dom/events.html#on_mouse_up"},{"doc":"redraw/dom/events","title":"on_mouse_up_capture","content":"pub fn on_mouse_up_capture(\n  handler: fn(MouseEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_mouse_up`](#on_mouse_up) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/mouseup_event)\nSynonyms:\nredraw/dom/events.on_mouse_up_capture\nredraw/dom/events on_mouse_up_capture","url":"redraw/dom/events.html#on_mouse_up_capture"},{"doc":"redraw/dom/events","title":"on_paste","content":"pub fn on_paste(handler: fn(ClipboardEvent) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/paste_event)\nSynonyms:\nredraw/dom/events.on_paste\nredraw/dom/events on_paste","url":"redraw/dom/events.html#on_paste"},{"doc":"redraw/dom/events","title":"on_paste_capture","content":"pub fn on_paste_capture(\n  handler: fn(ClipboardEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_paste`](#on_paste) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/paste_event)\nSynonyms:\nredraw/dom/events.on_paste_capture\nredraw/dom/events on_paste_capture","url":"redraw/dom/events.html#on_paste_capture"},{"doc":"redraw/dom/events","title":"on_pause","content":"pub fn on_pause(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/pause_event)\nSynonyms:\nredraw/dom/events.on_pause\nredraw/dom/events on_pause","url":"redraw/dom/events.html#on_pause"},{"doc":"redraw/dom/events","title":"on_pause_capture","content":"pub fn on_pause_capture(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n Alternative version of [`on_pause`](#on_pause) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/pause_event)\nSynonyms:\nredraw/dom/events.on_pause_capture\nredraw/dom/events on_pause_capture","url":"redraw/dom/events.html#on_pause_capture"},{"doc":"redraw/dom/events","title":"on_play","content":"pub fn on_play(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/play_event)\nSynonyms:\nredraw/dom/events.on_play\nredraw/dom/events on_play","url":"redraw/dom/events.html#on_play"},{"doc":"redraw/dom/events","title":"on_play_capture","content":"pub fn on_play_capture(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n Alternative version of [`on_play`](#on_play) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/play_event)\nSynonyms:\nredraw/dom/events.on_play_capture\nredraw/dom/events on_play_capture","url":"redraw/dom/events.html#on_play_capture"},{"doc":"redraw/dom/events","title":"on_playing","content":"pub fn on_playing(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/playing_event)\nSynonyms:\nredraw/dom/events.on_playing\nredraw/dom/events on_playing","url":"redraw/dom/events.html#on_playing"},{"doc":"redraw/dom/events","title":"on_playing_capture","content":"pub fn on_playing_capture(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n Alternative version of [`on_playing`](#on_playing) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/playing_event)\nSynonyms:\nredraw/dom/events.on_playing_capture\nredraw/dom/events on_playing_capture","url":"redraw/dom/events.html#on_playing_capture"},{"doc":"redraw/dom/events","title":"on_pointer_cancel","content":"pub fn on_pointer_cancel(\n  handler: fn(PointerEvent) -&gt; Nil,\n) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/pointercancel_event)\nSynonyms:\nredraw/dom/events.on_pointer_cancel\nredraw/dom/events on_pointer_cancel","url":"redraw/dom/events.html#on_pointer_cancel"},{"doc":"redraw/dom/events","title":"on_pointer_cancel_capture","content":"pub fn on_pointer_cancel_capture(\n  handler: fn(PointerEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_pointer_cancel`](#on_pointer_cancel) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/pointercancel_event)\nSynonyms:\nredraw/dom/events.on_pointer_cancel_capture\nredraw/dom/events on_pointer_cancel_capture","url":"redraw/dom/events.html#on_pointer_cancel_capture"},{"doc":"redraw/dom/events","title":"on_pointer_down","content":"pub fn on_pointer_down(\n  handler: fn(PointerEvent) -&gt; Nil,\n) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/pointerdown_event)\nSynonyms:\nredraw/dom/events.on_pointer_down\nredraw/dom/events on_pointer_down","url":"redraw/dom/events.html#on_pointer_down"},{"doc":"redraw/dom/events","title":"on_pointer_down_capture","content":"pub fn on_pointer_down_capture(\n  handler: fn(PointerEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_pointer_down`](#on_pointer_down) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/pointerdown_event)\nSynonyms:\nredraw/dom/events.on_pointer_down_capture\nredraw/dom/events on_pointer_down_capture","url":"redraw/dom/events.html#on_pointer_down_capture"},{"doc":"redraw/dom/events","title":"on_pointer_enter","content":"pub fn on_pointer_enter(\n  handler: fn(PointerEvent) -&gt; Nil,\n) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/pointerenter_event)\nSynonyms:\nredraw/dom/events.on_pointer_enter\nredraw/dom/events on_pointer_enter","url":"redraw/dom/events.html#on_pointer_enter"},{"doc":"redraw/dom/events","title":"on_pointer_leave","content":"pub fn on_pointer_leave(\n  handler: fn(PointerEvent) -&gt; Nil,\n) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/pointerleave_event)\nSynonyms:\nredraw/dom/events.on_pointer_leave\nredraw/dom/events on_pointer_leave","url":"redraw/dom/events.html#on_pointer_leave"},{"doc":"redraw/dom/events","title":"on_pointer_move","content":"pub fn on_pointer_move(\n  handler: fn(PointerEvent) -&gt; Nil,\n) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/pointermove_event)\nSynonyms:\nredraw/dom/events.on_pointer_move\nredraw/dom/events on_pointer_move","url":"redraw/dom/events.html#on_pointer_move"},{"doc":"redraw/dom/events","title":"on_pointer_move_capture","content":"pub fn on_pointer_move_capture(\n  handler: fn(PointerEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_pointer_move`](#on_pointer_move) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/pointermove_event)\nSynonyms:\nredraw/dom/events.on_pointer_move_capture\nredraw/dom/events on_pointer_move_capture","url":"redraw/dom/events.html#on_pointer_move_capture"},{"doc":"redraw/dom/events","title":"on_pointer_out","content":"pub fn on_pointer_out(\n  handler: fn(PointerEvent) -&gt; Nil,\n) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/pointerout_event)\nSynonyms:\nredraw/dom/events.on_pointer_out\nredraw/dom/events on_pointer_out","url":"redraw/dom/events.html#on_pointer_out"},{"doc":"redraw/dom/events","title":"on_pointer_out_capture","content":"pub fn on_pointer_out_capture(\n  handler: fn(PointerEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_pointer_out`](#on_pointer_out) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/pointerout_event)\nSynonyms:\nredraw/dom/events.on_pointer_out_capture\nredraw/dom/events on_pointer_out_capture","url":"redraw/dom/events.html#on_pointer_out_capture"},{"doc":"redraw/dom/events","title":"on_pointer_up","content":"pub fn on_pointer_up(\n  handler: fn(PointerEvent) -&gt; Nil,\n) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/pointerup_event)\nSynonyms:\nredraw/dom/events.on_pointer_up\nredraw/dom/events on_pointer_up","url":"redraw/dom/events.html#on_pointer_up"},{"doc":"redraw/dom/events","title":"on_pointer_up_capture","content":"pub fn on_pointer_up_capture(\n  handler: fn(PointerEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_pointer_up`](#on_pointer_up) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/pointerup_event)\nSynonyms:\nredraw/dom/events.on_pointer_up_capture\nredraw/dom/events on_pointer_up_capture","url":"redraw/dom/events.html#on_pointer_up_capture"},{"doc":"redraw/dom/events","title":"on_progress","content":"pub fn on_progress(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/progress_event)\nSynonyms:\nredraw/dom/events.on_progress\nredraw/dom/events on_progress","url":"redraw/dom/events.html#on_progress"},{"doc":"redraw/dom/events","title":"on_progress_capture","content":"pub fn on_progress_capture(\n  handler: fn(Event) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_progress`](#on_progress) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/progress_event)\nSynonyms:\nredraw/dom/events.on_progress_capture\nredraw/dom/events on_progress_capture","url":"redraw/dom/events.html#on_progress_capture"},{"doc":"redraw/dom/events","title":"on_rate_change","content":"pub fn on_rate_change(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/ratechange_event)\nSynonyms:\nredraw/dom/events.on_rate_change\nredraw/dom/events on_rate_change","url":"redraw/dom/events.html#on_rate_change"},{"doc":"redraw/dom/events","title":"on_rate_change_capture","content":"pub fn on_rate_change_capture(\n  handler: fn(Event) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_rate_change`](#on_rate_change) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/ratechange_event)\nSynonyms:\nredraw/dom/events.on_rate_change_capture\nredraw/dom/events on_rate_change_capture","url":"redraw/dom/events.html#on_rate_change_capture"},{"doc":"redraw/dom/events","title":"on_reset","content":"pub fn on_reset(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/reset_event)\nSynonyms:\nredraw/dom/events.on_reset\nredraw/dom/events on_reset","url":"redraw/dom/events.html#on_reset"},{"doc":"redraw/dom/events","title":"on_reset_capture","content":"pub fn on_reset_capture(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n Alternative version of [`on_reset`](#on_reset) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/reset_event)\nSynonyms:\nredraw/dom/events.on_reset_capture\nredraw/dom/events on_reset_capture","url":"redraw/dom/events.html#on_reset_capture"},{"doc":"redraw/dom/events","title":"on_resize","content":"pub fn on_resize(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/resize_event)\nSynonyms:\nredraw/dom/events.on_resize\nredraw/dom/events on_resize","url":"redraw/dom/events.html#on_resize"},{"doc":"redraw/dom/events","title":"on_resize_capture","content":"pub fn on_resize_capture(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n Alternative version of [`on_resize`](#on_resize) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/resize_event)\nSynonyms:\nredraw/dom/events.on_resize_capture\nredraw/dom/events on_resize_capture","url":"redraw/dom/events.html#on_resize_capture"},{"doc":"redraw/dom/events","title":"on_scroll","content":"pub fn on_scroll(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/scroll_event)\nSynonyms:\nredraw/dom/events.on_scroll\nredraw/dom/events on_scroll","url":"redraw/dom/events.html#on_scroll"},{"doc":"redraw/dom/events","title":"on_scroll_capture","content":"pub fn on_scroll_capture(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n Alternative version of [`on_scroll`](#on_scroll) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/scroll_event)\nSynonyms:\nredraw/dom/events.on_scroll_capture\nredraw/dom/events on_scroll_capture","url":"redraw/dom/events.html#on_scroll_capture"},{"doc":"redraw/dom/events","title":"on_seeked","content":"pub fn on_seeked(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/seeked_event)\nSynonyms:\nredraw/dom/events.on_seeked\nredraw/dom/events on_seeked","url":"redraw/dom/events.html#on_seeked"},{"doc":"redraw/dom/events","title":"on_seeked_capture","content":"pub fn on_seeked_capture(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n Alternative version of [`on_seeked`](#on_seeked) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/seeked_event)\nSynonyms:\nredraw/dom/events.on_seeked_capture\nredraw/dom/events on_seeked_capture","url":"redraw/dom/events.html#on_seeked_capture"},{"doc":"redraw/dom/events","title":"on_seeking","content":"pub fn on_seeking(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/seeking_event)\nSynonyms:\nredraw/dom/events.on_seeking\nredraw/dom/events on_seeking","url":"redraw/dom/events.html#on_seeking"},{"doc":"redraw/dom/events","title":"on_seeking_capture","content":"pub fn on_seeking_capture(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n Alternative version of [`on_seeking`](#on_seeking) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/seeking_event)\nSynonyms:\nredraw/dom/events.on_seeking_capture\nredraw/dom/events on_seeking_capture","url":"redraw/dom/events.html#on_seeking_capture"},{"doc":"redraw/dom/events","title":"on_select","content":"pub fn on_select(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/select_event)\nSynonyms:\nredraw/dom/events.on_select\nredraw/dom/events on_select","url":"redraw/dom/events.html#on_select"},{"doc":"redraw/dom/events","title":"on_select_capture","content":"pub fn on_select_capture(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n Alternative version of [`on_select`](#on_select) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/select_event)\nSynonyms:\nredraw/dom/events.on_select_capture\nredraw/dom/events on_select_capture","url":"redraw/dom/events.html#on_select_capture"},{"doc":"redraw/dom/events","title":"on_stalled","content":"pub fn on_stalled(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/stalled_event)\nSynonyms:\nredraw/dom/events.on_stalled\nredraw/dom/events on_stalled","url":"redraw/dom/events.html#on_stalled"},{"doc":"redraw/dom/events","title":"on_stalled_capture","content":"pub fn on_stalled_capture(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n Alternative version of [`on_stalled`](#on_stalled) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/stalled_event)\nSynonyms:\nredraw/dom/events.on_stalled_capture\nredraw/dom/events on_stalled_capture","url":"redraw/dom/events.html#on_stalled_capture"},{"doc":"redraw/dom/events","title":"on_submit","content":"pub fn on_submit(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/submit_event)\nSynonyms:\nredraw/dom/events.on_submit\nredraw/dom/events on_submit","url":"redraw/dom/events.html#on_submit"},{"doc":"redraw/dom/events","title":"on_submit_capture","content":"pub fn on_submit_capture(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n Alternative version of [`on_submit`](#on_submit) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/submit_event)\nSynonyms:\nredraw/dom/events.on_submit_capture\nredraw/dom/events on_submit_capture","url":"redraw/dom/events.html#on_submit_capture"},{"doc":"redraw/dom/events","title":"on_suspend","content":"pub fn on_suspend(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/suspend_event)\nSynonyms:\nredraw/dom/events.on_suspend\nredraw/dom/events on_suspend","url":"redraw/dom/events.html#on_suspend"},{"doc":"redraw/dom/events","title":"on_suspend_capture","content":"pub fn on_suspend_capture(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n Alternative version of [`on_suspend`](#on_suspend) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/suspend_event)\nSynonyms:\nredraw/dom/events.on_suspend_capture\nredraw/dom/events on_suspend_capture","url":"redraw/dom/events.html#on_suspend_capture"},{"doc":"redraw/dom/events","title":"on_time_update","content":"pub fn on_time_update(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/timeupdate_event)\nSynonyms:\nredraw/dom/events.on_time_update\nredraw/dom/events on_time_update","url":"redraw/dom/events.html#on_time_update"},{"doc":"redraw/dom/events","title":"on_time_update_capture","content":"pub fn on_time_update_capture(\n  handler: fn(Event) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_time_update`](#on_time_update) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/timeupdate_event)\nSynonyms:\nredraw/dom/events.on_time_update_capture\nredraw/dom/events on_time_update_capture","url":"redraw/dom/events.html#on_time_update_capture"},{"doc":"redraw/dom/events","title":"on_toggle","content":"pub fn on_toggle(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/toggle_event)\nSynonyms:\nredraw/dom/events.on_toggle\nredraw/dom/events on_toggle","url":"redraw/dom/events.html#on_toggle"},{"doc":"redraw/dom/events","title":"on_toggle_capture","content":"pub fn on_toggle_capture(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n Alternative version of [`on_toggle`](#on_toggle) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/toggle_event)\nSynonyms:\nredraw/dom/events.on_toggle_capture\nredraw/dom/events on_toggle_capture","url":"redraw/dom/events.html#on_toggle_capture"},{"doc":"redraw/dom/events","title":"on_touch_cancel","content":"pub fn on_touch_cancel(\n  handler: fn(TouchEvent) -&gt; Nil,\n) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/touchcancel_event)\nSynonyms:\nredraw/dom/events.on_touch_cancel\nredraw/dom/events on_touch_cancel","url":"redraw/dom/events.html#on_touch_cancel"},{"doc":"redraw/dom/events","title":"on_touch_cancel_capture","content":"pub fn on_touch_cancel_capture(\n  handler: fn(TouchEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_touch_cancel`](#on_touch_cancel) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/touchcancel_event)\nSynonyms:\nredraw/dom/events.on_touch_cancel_capture\nredraw/dom/events on_touch_cancel_capture","url":"redraw/dom/events.html#on_touch_cancel_capture"},{"doc":"redraw/dom/events","title":"on_touch_end","content":"pub fn on_touch_end(handler: fn(TouchEvent) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/touchend_event)\nSynonyms:\nredraw/dom/events.on_touch_end\nredraw/dom/events on_touch_end","url":"redraw/dom/events.html#on_touch_end"},{"doc":"redraw/dom/events","title":"on_touch_end_capture","content":"pub fn on_touch_end_capture(\n  handler: fn(TouchEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_touch_end`](#on_touch_end) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/touchend_event)\nSynonyms:\nredraw/dom/events.on_touch_end_capture\nredraw/dom/events on_touch_end_capture","url":"redraw/dom/events.html#on_touch_end_capture"},{"doc":"redraw/dom/events","title":"on_touch_move","content":"pub fn on_touch_move(handler: fn(TouchEvent) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/touchmove_event)\nSynonyms:\nredraw/dom/events.on_touch_move\nredraw/dom/events on_touch_move","url":"redraw/dom/events.html#on_touch_move"},{"doc":"redraw/dom/events","title":"on_touch_move_capture","content":"pub fn on_touch_move_capture(\n  handler: fn(TouchEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_touch_move`](#on_touch_move) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/touchmove_event)\nSynonyms:\nredraw/dom/events.on_touch_move_capture\nredraw/dom/events on_touch_move_capture","url":"redraw/dom/events.html#on_touch_move_capture"},{"doc":"redraw/dom/events","title":"on_touch_start","content":"pub fn on_touch_start(\n  handler: fn(TouchEvent) -&gt; Nil,\n) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/touchstart_event)\nSynonyms:\nredraw/dom/events.on_touch_start\nredraw/dom/events on_touch_start","url":"redraw/dom/events.html#on_touch_start"},{"doc":"redraw/dom/events","title":"on_touch_start_capture","content":"pub fn on_touch_start_capture(\n  handler: fn(TouchEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_touch_start`](#on_touch_start) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/touchstart_event)\nSynonyms:\nredraw/dom/events.on_touch_start_capture\nredraw/dom/events on_touch_start_capture","url":"redraw/dom/events.html#on_touch_start_capture"},{"doc":"redraw/dom/events","title":"on_transition_end","content":"pub fn on_transition_end(\n  handler: fn(TransitionEvent) -&gt; Nil,\n) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/transitionend_event)\nSynonyms:\nredraw/dom/events.on_transition_end\nredraw/dom/events on_transition_end","url":"redraw/dom/events.html#on_transition_end"},{"doc":"redraw/dom/events","title":"on_transition_end_capture","content":"pub fn on_transition_end_capture(\n  handler: fn(TransitionEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_transition_end`](#on_transition_end) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/transitionend_event)\nSynonyms:\nredraw/dom/events.on_transition_end_capture\nredraw/dom/events on_transition_end_capture","url":"redraw/dom/events.html#on_transition_end_capture"},{"doc":"redraw/dom/events","title":"on_volume_change","content":"pub fn on_volume_change(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/volumechange_event)\nSynonyms:\nredraw/dom/events.on_volume_change\nredraw/dom/events on_volume_change","url":"redraw/dom/events.html#on_volume_change"},{"doc":"redraw/dom/events","title":"on_volume_change_capture","content":"pub fn on_volume_change_capture(\n  handler: fn(Event) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_volume_change`](#on_volume_change) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/volumechange_event)\nSynonyms:\nredraw/dom/events.on_volume_change_capture\nredraw/dom/events on_volume_change_capture","url":"redraw/dom/events.html#on_volume_change_capture"},{"doc":"redraw/dom/events","title":"on_waiting","content":"pub fn on_waiting(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/waiting_event)\nSynonyms:\nredraw/dom/events.on_waiting\nredraw/dom/events on_waiting","url":"redraw/dom/events.html#on_waiting"},{"doc":"redraw/dom/events","title":"on_waiting_capture","content":"pub fn on_waiting_capture(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n Alternative version of [`on_waiting`](#on_waiting) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/waiting_event)\nSynonyms:\nredraw/dom/events.on_waiting_capture\nredraw/dom/events on_waiting_capture","url":"redraw/dom/events.html#on_waiting_capture"},{"doc":"redraw/dom/events","title":"on_wheel","content":"pub fn on_wheel(handler: fn(WheelEvent) -&gt; Nil) -&gt; Attribute\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/wheel_event)\nSynonyms:\nredraw/dom/events.on_wheel\nredraw/dom/events on_wheel","url":"redraw/dom/events.html#on_wheel"},{"doc":"redraw/dom/events","title":"on_wheel_capture","content":"pub fn on_wheel_capture(\n  handler: fn(WheelEvent) -&gt; Nil,\n) -&gt; Attribute\n Alternative version of [`on_wheel`](#on_wheel) that runs during\n [capture phase](https://react.dev/learn/responding-to-events#capture-phase-events). \\\n [Documentation](https://developer.mozilla.org/docs/Web/API/Element/wheel_event)\nSynonyms:\nredraw/dom/events.on_wheel_capture\nredraw/dom/events on_wheel_capture","url":"redraw/dom/events.html#on_wheel_capture"},{"doc":"redraw/dom/events","title":"redraw/dom/events","content":" Event listeners usable in React and in browser. \\\n All of them can be found in the\n [React.dev](https://react.dev/reference/react-dom/components/common#common)\n documentation for detailed information, as well as on\n [MDN](https://developer.mozilla.org/docs/Web/API/Element).\n\n Every event listener are defined as handlers, accepting an event, detailed\n in their documentation.","url":"redraw/dom/events.html"},{"doc":"redraw/dom/html","title":"a","content":"pub fn a(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/a)\nSynonyms:\nredraw/dom/html.a\nredraw/dom/html a","url":"redraw/dom/html.html#a"},{"doc":"redraw/dom/html","title":"abbr","content":"pub fn abbr(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/abbr)\nSynonyms:\nredraw/dom/html.abbr\nredraw/dom/html abbr","url":"redraw/dom/html.html#abbr"},{"doc":"redraw/dom/html","title":"address","content":"pub fn address(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/address)\nSynonyms:\nredraw/dom/html.address\nredraw/dom/html address","url":"redraw/dom/html.html#address"},{"doc":"redraw/dom/html","title":"area","content":"pub fn area(attrs: List(Attribute)) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/area)\nSynonyms:\nredraw/dom/html.area\nredraw/dom/html area","url":"redraw/dom/html.html#area"},{"doc":"redraw/dom/html","title":"article","content":"pub fn article(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/article)\nSynonyms:\nredraw/dom/html.article\nredraw/dom/html article","url":"redraw/dom/html.html#article"},{"doc":"redraw/dom/html","title":"aside","content":"pub fn aside(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/aside)\nSynonyms:\nredraw/dom/html.aside\nredraw/dom/html aside","url":"redraw/dom/html.html#aside"},{"doc":"redraw/dom/html","title":"audio","content":"pub fn audio(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/audio)\nSynonyms:\nredraw/dom/html.audio\nredraw/dom/html audio","url":"redraw/dom/html.html#audio"},{"doc":"redraw/dom/html","title":"b","content":"pub fn b(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/b)\nSynonyms:\nredraw/dom/html.b\nredraw/dom/html b","url":"redraw/dom/html.html#b"},{"doc":"redraw/dom/html","title":"base","content":"pub fn base(attrs: List(Attribute)) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/base)\nSynonyms:\nredraw/dom/html.base\nredraw/dom/html base","url":"redraw/dom/html.html#base"},{"doc":"redraw/dom/html","title":"bdi","content":"pub fn bdi(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/bdi)\nSynonyms:\nredraw/dom/html.bdi\nredraw/dom/html bdi","url":"redraw/dom/html.html#bdi"},{"doc":"redraw/dom/html","title":"bdo","content":"pub fn bdo(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/bdo)\nSynonyms:\nredraw/dom/html.bdo\nredraw/dom/html bdo","url":"redraw/dom/html.html#bdo"},{"doc":"redraw/dom/html","title":"blockquote","content":"pub fn blockquote(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/blockquote)\nSynonyms:\nredraw/dom/html.blockquote\nredraw/dom/html blockquote","url":"redraw/dom/html.html#blockquote"},{"doc":"redraw/dom/html","title":"body","content":"pub fn body(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/body)\nSynonyms:\nredraw/dom/html.body\nredraw/dom/html body","url":"redraw/dom/html.html#body"},{"doc":"redraw/dom/html","title":"br","content":"pub fn br(attrs: List(Attribute)) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/br)\nSynonyms:\nredraw/dom/html.br\nredraw/dom/html br","url":"redraw/dom/html.html#br"},{"doc":"redraw/dom/html","title":"button","content":"pub fn button(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/button)\nSynonyms:\nredraw/dom/html.button\nredraw/dom/html button","url":"redraw/dom/html.html#button"},{"doc":"redraw/dom/html","title":"canvas","content":"pub fn canvas(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/canvas)\nSynonyms:\nredraw/dom/html.canvas\nredraw/dom/html canvas","url":"redraw/dom/html.html#canvas"},{"doc":"redraw/dom/html","title":"caption","content":"pub fn caption(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/caption)\nSynonyms:\nredraw/dom/html.caption\nredraw/dom/html caption","url":"redraw/dom/html.html#caption"},{"doc":"redraw/dom/html","title":"cite","content":"pub fn cite(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/cite)\nSynonyms:\nredraw/dom/html.cite\nredraw/dom/html cite","url":"redraw/dom/html.html#cite"},{"doc":"redraw/dom/html","title":"code","content":"pub fn code(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/code)\nSynonyms:\nredraw/dom/html.code\nredraw/dom/html code","url":"redraw/dom/html.html#code"},{"doc":"redraw/dom/html","title":"col","content":"pub fn col(attrs: List(Attribute)) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/col)\nSynonyms:\nredraw/dom/html.col\nredraw/dom/html col","url":"redraw/dom/html.html#col"},{"doc":"redraw/dom/html","title":"colgroup","content":"pub fn colgroup(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/colgroup)\nSynonyms:\nredraw/dom/html.colgroup\nredraw/dom/html colgroup","url":"redraw/dom/html.html#colgroup"},{"doc":"redraw/dom/html","title":"data","content":"pub fn data(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/data)\nSynonyms:\nredraw/dom/html.data\nredraw/dom/html data","url":"redraw/dom/html.html#data"},{"doc":"redraw/dom/html","title":"datalist","content":"pub fn datalist(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/datalist)\nSynonyms:\nredraw/dom/html.datalist\nredraw/dom/html datalist","url":"redraw/dom/html.html#datalist"},{"doc":"redraw/dom/html","title":"dd","content":"pub fn dd(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/dd)\nSynonyms:\nredraw/dom/html.dd\nredraw/dom/html dd","url":"redraw/dom/html.html#dd"},{"doc":"redraw/dom/html","title":"del","content":"pub fn del(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/del)\nSynonyms:\nredraw/dom/html.del\nredraw/dom/html del","url":"redraw/dom/html.html#del"},{"doc":"redraw/dom/html","title":"details","content":"pub fn details(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/details)\nSynonyms:\nredraw/dom/html.details\nredraw/dom/html details","url":"redraw/dom/html.html#details"},{"doc":"redraw/dom/html","title":"dfn","content":"pub fn dfn(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/dfn)\nSynonyms:\nredraw/dom/html.dfn\nredraw/dom/html dfn","url":"redraw/dom/html.html#dfn"},{"doc":"redraw/dom/html","title":"dialog","content":"pub fn dialog(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/dialog)\nSynonyms:\nredraw/dom/html.dialog\nredraw/dom/html dialog","url":"redraw/dom/html.html#dialog"},{"doc":"redraw/dom/html","title":"div","content":"pub fn div(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/div)\nSynonyms:\nredraw/dom/html.div\nredraw/dom/html div","url":"redraw/dom/html.html#div"},{"doc":"redraw/dom/html","title":"dl","content":"pub fn dl(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/dl)\nSynonyms:\nredraw/dom/html.dl\nredraw/dom/html dl","url":"redraw/dom/html.html#dl"},{"doc":"redraw/dom/html","title":"dt","content":"pub fn dt(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/dt)\nSynonyms:\nredraw/dom/html.dt\nredraw/dom/html dt","url":"redraw/dom/html.html#dt"},{"doc":"redraw/dom/html","title":"em","content":"pub fn em(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/em)\nSynonyms:\nredraw/dom/html.em\nredraw/dom/html em","url":"redraw/dom/html.html#em"},{"doc":"redraw/dom/html","title":"embed","content":"pub fn embed(attrs: List(Attribute)) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/embed)\nSynonyms:\nredraw/dom/html.embed\nredraw/dom/html embed","url":"redraw/dom/html.html#embed"},{"doc":"redraw/dom/html","title":"fieldset","content":"pub fn fieldset(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/fieldset)\nSynonyms:\nredraw/dom/html.fieldset\nredraw/dom/html fieldset","url":"redraw/dom/html.html#fieldset"},{"doc":"redraw/dom/html","title":"figcaption","content":"pub fn figcaption(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/figcaption)\nSynonyms:\nredraw/dom/html.figcaption\nredraw/dom/html figcaption","url":"redraw/dom/html.html#figcaption"},{"doc":"redraw/dom/html","title":"figure","content":"pub fn figure(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/figure)\nSynonyms:\nredraw/dom/html.figure\nredraw/dom/html figure","url":"redraw/dom/html.html#figure"},{"doc":"redraw/dom/html","title":"footer","content":"pub fn footer(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/footer)\nSynonyms:\nredraw/dom/html.footer\nredraw/dom/html footer","url":"redraw/dom/html.html#footer"},{"doc":"redraw/dom/html","title":"form","content":"pub fn form(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/form)\nSynonyms:\nredraw/dom/html.form\nredraw/dom/html form","url":"redraw/dom/html.html#form"},{"doc":"redraw/dom/html","title":"h1","content":"pub fn h1(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/h1)\nSynonyms:\nredraw/dom/html.h1\nredraw/dom/html h1","url":"redraw/dom/html.html#h1"},{"doc":"redraw/dom/html","title":"h2","content":"pub fn h2(attrs: List(Attribute), children: a) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/h2)\nSynonyms:\nredraw/dom/html.h2\nredraw/dom/html h2","url":"redraw/dom/html.html#h2"},{"doc":"redraw/dom/html","title":"h3","content":"pub fn h3(attrs: List(Attribute), children: a) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/h3)\nSynonyms:\nredraw/dom/html.h3\nredraw/dom/html h3","url":"redraw/dom/html.html#h3"},{"doc":"redraw/dom/html","title":"h4","content":"pub fn h4(attrs: List(Attribute), children: a) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/h4)\nSynonyms:\nredraw/dom/html.h4\nredraw/dom/html h4","url":"redraw/dom/html.html#h4"},{"doc":"redraw/dom/html","title":"h5","content":"pub fn h5(attrs: List(Attribute), children: a) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/h5)\nSynonyms:\nredraw/dom/html.h5\nredraw/dom/html h5","url":"redraw/dom/html.html#h5"},{"doc":"redraw/dom/html","title":"h6","content":"pub fn h6(attrs: List(Attribute), children: a) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/h6)\nSynonyms:\nredraw/dom/html.h6\nredraw/dom/html h6","url":"redraw/dom/html.html#h6"},{"doc":"redraw/dom/html","title":"head","content":"pub fn head(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/head)\nSynonyms:\nredraw/dom/html.head\nredraw/dom/html head","url":"redraw/dom/html.html#head"},{"doc":"redraw/dom/html","title":"header","content":"pub fn header(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/header)\nSynonyms:\nredraw/dom/html.header\nredraw/dom/html header","url":"redraw/dom/html.html#header"},{"doc":"redraw/dom/html","title":"hgroup","content":"pub fn hgroup(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/hgroup)\nSynonyms:\nredraw/dom/html.hgroup\nredraw/dom/html hgroup","url":"redraw/dom/html.html#hgroup"},{"doc":"redraw/dom/html","title":"hr","content":"pub fn hr(attrs: List(Attribute)) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/hr)\nSynonyms:\nredraw/dom/html.hr\nredraw/dom/html hr","url":"redraw/dom/html.html#hr"},{"doc":"redraw/dom/html","title":"html","content":"pub fn html(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/html)\nSynonyms:\nredraw/dom/html.html\nredraw/dom/html html","url":"redraw/dom/html.html#html"},{"doc":"redraw/dom/html","title":"i","content":"pub fn i(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/i)\nSynonyms:\nredraw/dom/html.i\nredraw/dom/html i","url":"redraw/dom/html.html#i"},{"doc":"redraw/dom/html","title":"iframe","content":"pub fn iframe(attrs: List(Attribute)) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/iframe)\nSynonyms:\nredraw/dom/html.iframe\nredraw/dom/html iframe","url":"redraw/dom/html.html#iframe"},{"doc":"redraw/dom/html","title":"img","content":"pub fn img(attrs: List(Attribute)) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/img)\nSynonyms:\nredraw/dom/html.img\nredraw/dom/html img","url":"redraw/dom/html.html#img"},{"doc":"redraw/dom/html","title":"input","content":"pub fn input(attrs: List(Attribute)) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/input)\nSynonyms:\nredraw/dom/html.input\nredraw/dom/html input","url":"redraw/dom/html.html#input"},{"doc":"redraw/dom/html","title":"ins","content":"pub fn ins(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/ins)\nSynonyms:\nredraw/dom/html.ins\nredraw/dom/html ins","url":"redraw/dom/html.html#ins"},{"doc":"redraw/dom/html","title":"kbd","content":"pub fn kbd(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/kbd)\nSynonyms:\nredraw/dom/html.kbd\nredraw/dom/html kbd","url":"redraw/dom/html.html#kbd"},{"doc":"redraw/dom/html","title":"label","content":"pub fn label(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/label)\nSynonyms:\nredraw/dom/html.label\nredraw/dom/html label","url":"redraw/dom/html.html#label"},{"doc":"redraw/dom/html","title":"legend","content":"pub fn legend(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/legend)\nSynonyms:\nredraw/dom/html.legend\nredraw/dom/html legend","url":"redraw/dom/html.html#legend"},{"doc":"redraw/dom/html","title":"li","content":"pub fn li(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/li)\nSynonyms:\nredraw/dom/html.li\nredraw/dom/html li","url":"redraw/dom/html.html#li"},{"doc":"redraw/dom/html","title":"link","content":"pub fn link(attrs: List(Attribute)) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/link)\nSynonyms:\nredraw/dom/html.link\nredraw/dom/html link","url":"redraw/dom/html.html#link"},{"doc":"redraw/dom/html","title":"main","content":"pub fn main(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/main)\nSynonyms:\nredraw/dom/html.main\nredraw/dom/html main","url":"redraw/dom/html.html#main"},{"doc":"redraw/dom/html","title":"map","content":"pub fn map(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/map)\nSynonyms:\nredraw/dom/html.map\nredraw/dom/html map","url":"redraw/dom/html.html#map"},{"doc":"redraw/dom/html","title":"mark","content":"pub fn mark(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/mark)\nSynonyms:\nredraw/dom/html.mark\nredraw/dom/html mark","url":"redraw/dom/html.html#mark"},{"doc":"redraw/dom/html","title":"menu","content":"pub fn menu(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/menu)\nSynonyms:\nredraw/dom/html.menu\nredraw/dom/html menu","url":"redraw/dom/html.html#menu"},{"doc":"redraw/dom/html","title":"meta","content":"pub fn meta(attrs: List(Attribute)) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/meta)\nSynonyms:\nredraw/dom/html.meta\nredraw/dom/html meta","url":"redraw/dom/html.html#meta"},{"doc":"redraw/dom/html","title":"meter","content":"pub fn meter(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/meter)\nSynonyms:\nredraw/dom/html.meter\nredraw/dom/html meter","url":"redraw/dom/html.html#meter"},{"doc":"redraw/dom/html","title":"nav","content":"pub fn nav(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/nav)\nSynonyms:\nredraw/dom/html.nav\nredraw/dom/html nav","url":"redraw/dom/html.html#nav"},{"doc":"redraw/dom/html","title":"none","content":"pub fn none() -&gt; Component\n Empty node. Does not render anything in the DOM.\nSynonyms:\nredraw/dom/html.none\nredraw/dom/html none","url":"redraw/dom/html.html#none"},{"doc":"redraw/dom/html","title":"noscript","content":"pub fn noscript(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/noscript)\nSynonyms:\nredraw/dom/html.noscript\nredraw/dom/html noscript","url":"redraw/dom/html.html#noscript"},{"doc":"redraw/dom/html","title":"object","content":"pub fn object(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/object)\nSynonyms:\nredraw/dom/html.object\nredraw/dom/html object","url":"redraw/dom/html.html#object"},{"doc":"redraw/dom/html","title":"ol","content":"pub fn ol(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/ol)\nSynonyms:\nredraw/dom/html.ol\nredraw/dom/html ol","url":"redraw/dom/html.html#ol"},{"doc":"redraw/dom/html","title":"optgroup","content":"pub fn optgroup(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/optgroup)\nSynonyms:\nredraw/dom/html.optgroup\nredraw/dom/html optgroup","url":"redraw/dom/html.html#optgroup"},{"doc":"redraw/dom/html","title":"option","content":"pub fn option(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/option)\nSynonyms:\nredraw/dom/html.option\nredraw/dom/html option","url":"redraw/dom/html.html#option"},{"doc":"redraw/dom/html","title":"output","content":"pub fn output(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/output)\nSynonyms:\nredraw/dom/html.output\nredraw/dom/html output","url":"redraw/dom/html.html#output"},{"doc":"redraw/dom/html","title":"p","content":"pub fn p(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/p)\nSynonyms:\nredraw/dom/html.p\nredraw/dom/html p","url":"redraw/dom/html.html#p"},{"doc":"redraw/dom/html","title":"picture","content":"pub fn picture(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/picture)\nSynonyms:\nredraw/dom/html.picture\nredraw/dom/html picture","url":"redraw/dom/html.html#picture"},{"doc":"redraw/dom/html","title":"pre","content":"pub fn pre(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/pre)\nSynonyms:\nredraw/dom/html.pre\nredraw/dom/html pre","url":"redraw/dom/html.html#pre"},{"doc":"redraw/dom/html","title":"progress","content":"pub fn progress(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/progress)\nSynonyms:\nredraw/dom/html.progress\nredraw/dom/html progress","url":"redraw/dom/html.html#progress"},{"doc":"redraw/dom/html","title":"q","content":"pub fn q(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/q)\nSynonyms:\nredraw/dom/html.q\nredraw/dom/html q","url":"redraw/dom/html.html#q"},{"doc":"redraw/dom/html","title":"rp","content":"pub fn rp(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/rp)\nSynonyms:\nredraw/dom/html.rp\nredraw/dom/html rp","url":"redraw/dom/html.html#rp"},{"doc":"redraw/dom/html","title":"rt","content":"pub fn rt(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/rt)\nSynonyms:\nredraw/dom/html.rt\nredraw/dom/html rt","url":"redraw/dom/html.html#rt"},{"doc":"redraw/dom/html","title":"ruby","content":"pub fn ruby(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/ruby)\nSynonyms:\nredraw/dom/html.ruby\nredraw/dom/html ruby","url":"redraw/dom/html.html#ruby"},{"doc":"redraw/dom/html","title":"s","content":"pub fn s(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/s)\nSynonyms:\nredraw/dom/html.s\nredraw/dom/html s","url":"redraw/dom/html.html#s"},{"doc":"redraw/dom/html","title":"samp","content":"pub fn samp(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/samp)\nSynonyms:\nredraw/dom/html.samp\nredraw/dom/html samp","url":"redraw/dom/html.html#samp"},{"doc":"redraw/dom/html","title":"script","content":"pub fn script(\n  attrs: List(Attribute),\n  script: String,\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/script)\nSynonyms:\nredraw/dom/html.script\nredraw/dom/html script","url":"redraw/dom/html.html#script"},{"doc":"redraw/dom/html","title":"section","content":"pub fn section(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/section)\nSynonyms:\nredraw/dom/html.section\nredraw/dom/html section","url":"redraw/dom/html.html#section"},{"doc":"redraw/dom/html","title":"select","content":"pub fn select(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/select)\nSynonyms:\nredraw/dom/html.select\nredraw/dom/html select","url":"redraw/dom/html.html#select"},{"doc":"redraw/dom/html","title":"slot","content":"pub fn slot(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/slot)\nSynonyms:\nredraw/dom/html.slot\nredraw/dom/html slot","url":"redraw/dom/html.html#slot"},{"doc":"redraw/dom/html","title":"small","content":"pub fn small(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/small)\nSynonyms:\nredraw/dom/html.small\nredraw/dom/html small","url":"redraw/dom/html.html#small"},{"doc":"redraw/dom/html","title":"source","content":"pub fn source(attrs: List(Attribute)) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/source)\nSynonyms:\nredraw/dom/html.source\nredraw/dom/html source","url":"redraw/dom/html.html#source"},{"doc":"redraw/dom/html","title":"span","content":"pub fn span(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/span)\nSynonyms:\nredraw/dom/html.span\nredraw/dom/html span","url":"redraw/dom/html.html#span"},{"doc":"redraw/dom/html","title":"strong","content":"pub fn strong(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/strong)\nSynonyms:\nredraw/dom/html.strong\nredraw/dom/html strong","url":"redraw/dom/html.html#strong"},{"doc":"redraw/dom/html","title":"style","content":"pub fn style(\n  attrs: List(Attribute),\n  content: String,\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/style)\nSynonyms:\nredraw/dom/html.style\nredraw/dom/html style","url":"redraw/dom/html.html#style"},{"doc":"redraw/dom/html","title":"sub","content":"pub fn sub(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/sub)\nSynonyms:\nredraw/dom/html.sub\nredraw/dom/html sub","url":"redraw/dom/html.html#sub"},{"doc":"redraw/dom/html","title":"summary","content":"pub fn summary(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/summary)\nSynonyms:\nredraw/dom/html.summary\nredraw/dom/html summary","url":"redraw/dom/html.html#summary"},{"doc":"redraw/dom/html","title":"sup","content":"pub fn sup(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/sup)\nSynonyms:\nredraw/dom/html.sup\nredraw/dom/html sup","url":"redraw/dom/html.html#sup"},{"doc":"redraw/dom/html","title":"table","content":"pub fn table(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/table)\nSynonyms:\nredraw/dom/html.table\nredraw/dom/html table","url":"redraw/dom/html.html#table"},{"doc":"redraw/dom/html","title":"tbody","content":"pub fn tbody(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/tbody)\nSynonyms:\nredraw/dom/html.tbody\nredraw/dom/html tbody","url":"redraw/dom/html.html#tbody"},{"doc":"redraw/dom/html","title":"td","content":"pub fn td(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/td)\nSynonyms:\nredraw/dom/html.td\nredraw/dom/html td","url":"redraw/dom/html.html#td"},{"doc":"redraw/dom/html","title":"template","content":"pub fn template(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/template)\nSynonyms:\nredraw/dom/html.template\nredraw/dom/html template","url":"redraw/dom/html.html#template"},{"doc":"redraw/dom/html","title":"text","content":"pub fn text(content: String) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/API/Text)\nSynonyms:\nredraw/dom/html.text\nredraw/dom/html text","url":"redraw/dom/html.html#text"},{"doc":"redraw/dom/html","title":"textarea","content":"pub fn textarea(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/textarea)\nSynonyms:\nredraw/dom/html.textarea\nredraw/dom/html textarea","url":"redraw/dom/html.html#textarea"},{"doc":"redraw/dom/html","title":"tfoot","content":"pub fn tfoot(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/tfoot)\nSynonyms:\nredraw/dom/html.tfoot\nredraw/dom/html tfoot","url":"redraw/dom/html.html#tfoot"},{"doc":"redraw/dom/html","title":"th","content":"pub fn th(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/th)\nSynonyms:\nredraw/dom/html.th\nredraw/dom/html th","url":"redraw/dom/html.html#th"},{"doc":"redraw/dom/html","title":"thead","content":"pub fn thead(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/thead)\nSynonyms:\nredraw/dom/html.thead\nredraw/dom/html thead","url":"redraw/dom/html.html#thead"},{"doc":"redraw/dom/html","title":"time","content":"pub fn time(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/time)\nSynonyms:\nredraw/dom/html.time\nredraw/dom/html time","url":"redraw/dom/html.html#time"},{"doc":"redraw/dom/html","title":"title","content":"pub fn title(\n  attrs: List(Attribute),\n  content: String,\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/title)\nSynonyms:\nredraw/dom/html.title\nredraw/dom/html title","url":"redraw/dom/html.html#title"},{"doc":"redraw/dom/html","title":"tr","content":"pub fn tr(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/tr)\nSynonyms:\nredraw/dom/html.tr\nredraw/dom/html tr","url":"redraw/dom/html.html#tr"},{"doc":"redraw/dom/html","title":"track","content":"pub fn track(attrs: List(Attribute)) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/track)\nSynonyms:\nredraw/dom/html.track\nredraw/dom/html track","url":"redraw/dom/html.html#track"},{"doc":"redraw/dom/html","title":"u","content":"pub fn u(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/u)\nSynonyms:\nredraw/dom/html.u\nredraw/dom/html u","url":"redraw/dom/html.html#u"},{"doc":"redraw/dom/html","title":"ul","content":"pub fn ul(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/ul)\nSynonyms:\nredraw/dom/html.ul\nredraw/dom/html ul","url":"redraw/dom/html.html#ul"},{"doc":"redraw/dom/html","title":"var","content":"pub fn var(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/var)\nSynonyms:\nredraw/dom/html.var\nredraw/dom/html var","url":"redraw/dom/html.html#var"},{"doc":"redraw/dom/html","title":"video","content":"pub fn video(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/video)\nSynonyms:\nredraw/dom/html.video\nredraw/dom/html video","url":"redraw/dom/html.html#video"},{"doc":"redraw/dom/html","title":"wbr","content":"pub fn wbr(attrs: List(Attribute)) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/HTML/Element/wbr)\nSynonyms:\nredraw/dom/html.wbr\nredraw/dom/html wbr","url":"redraw/dom/html.html#wbr"},{"doc":"redraw/dom/html","title":"redraw/dom/html","content":" All built-in browser components, such as `&lt;div&gt;`, `&lt;span&gt;`, etc. support\n common attributes and events. \\\n To stay compatible with the Lustre API, Redraw defines the entire set of\n HTML elements. They&#39;re instantiated with JSX under-the-hood, and requires\n a modern runtime to get them working.\n\n [Find detailed documentation on MDN](https://developer.mozilla.org/docs/Web/HTML/Element).","url":"redraw/dom/html.html"},{"doc":"redraw/dom/svg","title":"a","content":"pub fn a(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/a)\nSynonyms:\nredraw/dom/svg.a\nredraw/dom/svg a","url":"redraw/dom/svg.html#a"},{"doc":"redraw/dom/svg","title":"animate","content":"pub fn animate(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/animate)\nSynonyms:\nredraw/dom/svg.animate\nredraw/dom/svg animate","url":"redraw/dom/svg.html#animate"},{"doc":"redraw/dom/svg","title":"animate_motion","content":"pub fn animate_motion(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/animateMotion)\nSynonyms:\nredraw/dom/svg.animate_motion\nredraw/dom/svg animate_motion","url":"redraw/dom/svg.html#animate_motion"},{"doc":"redraw/dom/svg","title":"animate_transform","content":"pub fn animate_transform(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/animateTransform)\nSynonyms:\nredraw/dom/svg.animate_transform\nredraw/dom/svg animate_transform","url":"redraw/dom/svg.html#animate_transform"},{"doc":"redraw/dom/svg","title":"circle","content":"pub fn circle(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/circle)\nSynonyms:\nredraw/dom/svg.circle\nredraw/dom/svg circle","url":"redraw/dom/svg.html#circle"},{"doc":"redraw/dom/svg","title":"clip_path","content":"pub fn clip_path(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/clipPath)\nSynonyms:\nredraw/dom/svg.clip_path\nredraw/dom/svg clip_path","url":"redraw/dom/svg.html#clip_path"},{"doc":"redraw/dom/svg","title":"defs","content":"pub fn defs(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/defs)\nSynonyms:\nredraw/dom/svg.defs\nredraw/dom/svg defs","url":"redraw/dom/svg.html#defs"},{"doc":"redraw/dom/svg","title":"desc","content":"pub fn desc(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/desc)\nSynonyms:\nredraw/dom/svg.desc\nredraw/dom/svg desc","url":"redraw/dom/svg.html#desc"},{"doc":"redraw/dom/svg","title":"discard","content":"pub fn discard(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/discard)\nSynonyms:\nredraw/dom/svg.discard\nredraw/dom/svg discard","url":"redraw/dom/svg.html#discard"},{"doc":"redraw/dom/svg","title":"ellipse","content":"pub fn ellipse(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/ellipse)\nSynonyms:\nredraw/dom/svg.ellipse\nredraw/dom/svg ellipse","url":"redraw/dom/svg.html#ellipse"},{"doc":"redraw/dom/svg","title":"fe_blend","content":"pub fn fe_blend(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/feBlend)\nSynonyms:\nredraw/dom/svg.fe_blend\nredraw/dom/svg fe_blend","url":"redraw/dom/svg.html#fe_blend"},{"doc":"redraw/dom/svg","title":"fe_color_matrix","content":"pub fn fe_color_matrix(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/feColorMatrix)\nSynonyms:\nredraw/dom/svg.fe_color_matrix\nredraw/dom/svg fe_color_matrix","url":"redraw/dom/svg.html#fe_color_matrix"},{"doc":"redraw/dom/svg","title":"fe_component_transfer","content":"pub fn fe_component_transfer(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/feComponentTransfer)\nSynonyms:\nredraw/dom/svg.fe_component_transfer\nredraw/dom/svg fe_component_transfer","url":"redraw/dom/svg.html#fe_component_transfer"},{"doc":"redraw/dom/svg","title":"fe_composite","content":"pub fn fe_composite(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/feComposite)\nSynonyms:\nredraw/dom/svg.fe_composite\nredraw/dom/svg fe_composite","url":"redraw/dom/svg.html#fe_composite"},{"doc":"redraw/dom/svg","title":"fe_convolve_matrix","content":"pub fn fe_convolve_matrix(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/feConvolveMatrix)\nSynonyms:\nredraw/dom/svg.fe_convolve_matrix\nredraw/dom/svg fe_convolve_matrix","url":"redraw/dom/svg.html#fe_convolve_matrix"},{"doc":"redraw/dom/svg","title":"fe_diffuse_lighting","content":"pub fn fe_diffuse_lighting(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/feDiffuseLighting)\nSynonyms:\nredraw/dom/svg.fe_diffuse_lighting\nredraw/dom/svg fe_diffuse_lighting","url":"redraw/dom/svg.html#fe_diffuse_lighting"},{"doc":"redraw/dom/svg","title":"fe_displacement_map","content":"pub fn fe_displacement_map(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/feDisplacementMap)\nSynonyms:\nredraw/dom/svg.fe_displacement_map\nredraw/dom/svg fe_displacement_map","url":"redraw/dom/svg.html#fe_displacement_map"},{"doc":"redraw/dom/svg","title":"fe_distant_light","content":"pub fn fe_distant_light(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/feDistantLight)\nSynonyms:\nredraw/dom/svg.fe_distant_light\nredraw/dom/svg fe_distant_light","url":"redraw/dom/svg.html#fe_distant_light"},{"doc":"redraw/dom/svg","title":"fe_drop_shadow","content":"pub fn fe_drop_shadow(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/feDropShadow)\nSynonyms:\nredraw/dom/svg.fe_drop_shadow\nredraw/dom/svg fe_drop_shadow","url":"redraw/dom/svg.html#fe_drop_shadow"},{"doc":"redraw/dom/svg","title":"fe_flood","content":"pub fn fe_flood(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/feFlood)\nSynonyms:\nredraw/dom/svg.fe_flood\nredraw/dom/svg fe_flood","url":"redraw/dom/svg.html#fe_flood"},{"doc":"redraw/dom/svg","title":"fe_func_a","content":"pub fn fe_func_a(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/feFuncA)\nSynonyms:\nredraw/dom/svg.fe_func_a\nredraw/dom/svg fe_func_a","url":"redraw/dom/svg.html#fe_func_a"},{"doc":"redraw/dom/svg","title":"fe_func_b","content":"pub fn fe_func_b(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/feFuncB)\nSynonyms:\nredraw/dom/svg.fe_func_b\nredraw/dom/svg fe_func_b","url":"redraw/dom/svg.html#fe_func_b"},{"doc":"redraw/dom/svg","title":"fe_func_g","content":"pub fn fe_func_g(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/feFuncG)\nSynonyms:\nredraw/dom/svg.fe_func_g\nredraw/dom/svg fe_func_g","url":"redraw/dom/svg.html#fe_func_g"},{"doc":"redraw/dom/svg","title":"fe_func_r","content":"pub fn fe_func_r(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/feFuncR)\nSynonyms:\nredraw/dom/svg.fe_func_r\nredraw/dom/svg fe_func_r","url":"redraw/dom/svg.html#fe_func_r"},{"doc":"redraw/dom/svg","title":"fe_gaussian_blur","content":"pub fn fe_gaussian_blur(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/feGaussianBlur)\nSynonyms:\nredraw/dom/svg.fe_gaussian_blur\nredraw/dom/svg fe_gaussian_blur","url":"redraw/dom/svg.html#fe_gaussian_blur"},{"doc":"redraw/dom/svg","title":"fe_image","content":"pub fn fe_image(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/feImage)\nSynonyms:\nredraw/dom/svg.fe_image\nredraw/dom/svg fe_image","url":"redraw/dom/svg.html#fe_image"},{"doc":"redraw/dom/svg","title":"fe_merge","content":"pub fn fe_merge(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/feMerge)\nSynonyms:\nredraw/dom/svg.fe_merge\nredraw/dom/svg fe_merge","url":"redraw/dom/svg.html#fe_merge"},{"doc":"redraw/dom/svg","title":"fe_merge_node","content":"pub fn fe_merge_node(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/feMergeNode)\nSynonyms:\nredraw/dom/svg.fe_merge_node\nredraw/dom/svg fe_merge_node","url":"redraw/dom/svg.html#fe_merge_node"},{"doc":"redraw/dom/svg","title":"fe_morphology","content":"pub fn fe_morphology(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/feMorphology)\nSynonyms:\nredraw/dom/svg.fe_morphology\nredraw/dom/svg fe_morphology","url":"redraw/dom/svg.html#fe_morphology"},{"doc":"redraw/dom/svg","title":"fe_offset","content":"pub fn fe_offset(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/feOffset)\nSynonyms:\nredraw/dom/svg.fe_offset\nredraw/dom/svg fe_offset","url":"redraw/dom/svg.html#fe_offset"},{"doc":"redraw/dom/svg","title":"fe_point_light","content":"pub fn fe_point_light(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/fePointLight)\nSynonyms:\nredraw/dom/svg.fe_point_light\nredraw/dom/svg fe_point_light","url":"redraw/dom/svg.html#fe_point_light"},{"doc":"redraw/dom/svg","title":"fe_specular_lighting","content":"pub fn fe_specular_lighting(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/feSpecularLighting)\nSynonyms:\nredraw/dom/svg.fe_specular_lighting\nredraw/dom/svg fe_specular_lighting","url":"redraw/dom/svg.html#fe_specular_lighting"},{"doc":"redraw/dom/svg","title":"fe_spot_light","content":"pub fn fe_spot_light(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/feSpotLight)\nSynonyms:\nredraw/dom/svg.fe_spot_light\nredraw/dom/svg fe_spot_light","url":"redraw/dom/svg.html#fe_spot_light"},{"doc":"redraw/dom/svg","title":"fe_tile","content":"pub fn fe_tile(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/feTile)\nSynonyms:\nredraw/dom/svg.fe_tile\nredraw/dom/svg fe_tile","url":"redraw/dom/svg.html#fe_tile"},{"doc":"redraw/dom/svg","title":"fe_turbulence","content":"pub fn fe_turbulence(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/feTurbulence)\nSynonyms:\nredraw/dom/svg.fe_turbulence\nredraw/dom/svg fe_turbulence","url":"redraw/dom/svg.html#fe_turbulence"},{"doc":"redraw/dom/svg","title":"filter","content":"pub fn filter(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/filter)\nSynonyms:\nredraw/dom/svg.filter\nredraw/dom/svg filter","url":"redraw/dom/svg.html#filter"},{"doc":"redraw/dom/svg","title":"foreign_object","content":"pub fn foreign_object(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/foreignObject)\nSynonyms:\nredraw/dom/svg.foreign_object\nredraw/dom/svg foreign_object","url":"redraw/dom/svg.html#foreign_object"},{"doc":"redraw/dom/svg","title":"g","content":"pub fn g(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/g)\nSynonyms:\nredraw/dom/svg.g\nredraw/dom/svg g","url":"redraw/dom/svg.html#g"},{"doc":"redraw/dom/svg","title":"hatch","content":"pub fn hatch(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/hatch)\nSynonyms:\nredraw/dom/svg.hatch\nredraw/dom/svg hatch","url":"redraw/dom/svg.html#hatch"},{"doc":"redraw/dom/svg","title":"hatchpath","content":"pub fn hatchpath(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/hatchpath)\nSynonyms:\nredraw/dom/svg.hatchpath\nredraw/dom/svg hatchpath","url":"redraw/dom/svg.html#hatchpath"},{"doc":"redraw/dom/svg","title":"image","content":"pub fn image(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/image)\nSynonyms:\nredraw/dom/svg.image\nredraw/dom/svg image","url":"redraw/dom/svg.html#image"},{"doc":"redraw/dom/svg","title":"line","content":"pub fn line(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/line)\nSynonyms:\nredraw/dom/svg.line\nredraw/dom/svg line","url":"redraw/dom/svg.html#line"},{"doc":"redraw/dom/svg","title":"linear_gradient","content":"pub fn linear_gradient(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/linearGradient)\nSynonyms:\nredraw/dom/svg.linear_gradient\nredraw/dom/svg linear_gradient","url":"redraw/dom/svg.html#linear_gradient"},{"doc":"redraw/dom/svg","title":"marker","content":"pub fn marker(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/marker)\nSynonyms:\nredraw/dom/svg.marker\nredraw/dom/svg marker","url":"redraw/dom/svg.html#marker"},{"doc":"redraw/dom/svg","title":"mask","content":"pub fn mask(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/mask)\nSynonyms:\nredraw/dom/svg.mask\nredraw/dom/svg mask","url":"redraw/dom/svg.html#mask"},{"doc":"redraw/dom/svg","title":"metadata","content":"pub fn metadata(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/metadata)\nSynonyms:\nredraw/dom/svg.metadata\nredraw/dom/svg metadata","url":"redraw/dom/svg.html#metadata"},{"doc":"redraw/dom/svg","title":"mpath","content":"pub fn mpath(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/mpath)\nSynonyms:\nredraw/dom/svg.mpath\nredraw/dom/svg mpath","url":"redraw/dom/svg.html#mpath"},{"doc":"redraw/dom/svg","title":"path","content":"pub fn path(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/path)\nSynonyms:\nredraw/dom/svg.path\nredraw/dom/svg path","url":"redraw/dom/svg.html#path"},{"doc":"redraw/dom/svg","title":"pattern","content":"pub fn pattern(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/pattern)\nSynonyms:\nredraw/dom/svg.pattern\nredraw/dom/svg pattern","url":"redraw/dom/svg.html#pattern"},{"doc":"redraw/dom/svg","title":"polygon","content":"pub fn polygon(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/polygon)\nSynonyms:\nredraw/dom/svg.polygon\nredraw/dom/svg polygon","url":"redraw/dom/svg.html#polygon"},{"doc":"redraw/dom/svg","title":"polyline","content":"pub fn polyline(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/polyline)\nSynonyms:\nredraw/dom/svg.polyline\nredraw/dom/svg polyline","url":"redraw/dom/svg.html#polyline"},{"doc":"redraw/dom/svg","title":"radial_gradient","content":"pub fn radial_gradient(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/radialGradient)\nSynonyms:\nredraw/dom/svg.radial_gradient\nredraw/dom/svg radial_gradient","url":"redraw/dom/svg.html#radial_gradient"},{"doc":"redraw/dom/svg","title":"rect","content":"pub fn rect(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/rect)\nSynonyms:\nredraw/dom/svg.rect\nredraw/dom/svg rect","url":"redraw/dom/svg.html#rect"},{"doc":"redraw/dom/svg","title":"script","content":"pub fn script(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/script)\nSynonyms:\nredraw/dom/svg.script\nredraw/dom/svg script","url":"redraw/dom/svg.html#script"},{"doc":"redraw/dom/svg","title":"set","content":"pub fn set(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/set)\nSynonyms:\nredraw/dom/svg.set\nredraw/dom/svg set","url":"redraw/dom/svg.html#set"},{"doc":"redraw/dom/svg","title":"stop","content":"pub fn stop(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/stop)\nSynonyms:\nredraw/dom/svg.stop\nredraw/dom/svg stop","url":"redraw/dom/svg.html#stop"},{"doc":"redraw/dom/svg","title":"style","content":"pub fn style(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/style)\nSynonyms:\nredraw/dom/svg.style\nredraw/dom/svg style","url":"redraw/dom/svg.html#style"},{"doc":"redraw/dom/svg","title":"svg","content":"pub fn svg(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/svg)\nSynonyms:\nredraw/dom/svg.svg\nredraw/dom/svg svg","url":"redraw/dom/svg.html#svg"},{"doc":"redraw/dom/svg","title":"switch","content":"pub fn switch(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/switch)\nSynonyms:\nredraw/dom/svg.switch\nredraw/dom/svg switch","url":"redraw/dom/svg.html#switch"},{"doc":"redraw/dom/svg","title":"symbol","content":"pub fn symbol(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/symbol)\nSynonyms:\nredraw/dom/svg.symbol\nredraw/dom/svg symbol","url":"redraw/dom/svg.html#symbol"},{"doc":"redraw/dom/svg","title":"text","content":"pub fn text(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/text)\nSynonyms:\nredraw/dom/svg.text\nredraw/dom/svg text","url":"redraw/dom/svg.html#text"},{"doc":"redraw/dom/svg","title":"text_path","content":"pub fn text_path(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/textPath)\nSynonyms:\nredraw/dom/svg.text_path\nredraw/dom/svg text_path","url":"redraw/dom/svg.html#text_path"},{"doc":"redraw/dom/svg","title":"title","content":"pub fn title(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/title)\nSynonyms:\nredraw/dom/svg.title\nredraw/dom/svg title","url":"redraw/dom/svg.html#title"},{"doc":"redraw/dom/svg","title":"tspan","content":"pub fn tspan(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/tspan)\nSynonyms:\nredraw/dom/svg.tspan\nredraw/dom/svg tspan","url":"redraw/dom/svg.html#tspan"},{"doc":"redraw/dom/svg","title":"use_","content":"pub fn use_(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/use)\nSynonyms:\nredraw/dom/svg.use_\nredraw/dom/svg use_","url":"redraw/dom/svg.html#use_"},{"doc":"redraw/dom/svg","title":"view","content":"pub fn view(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n [Documentation](https://developer.mozilla.org/docs/Web/SVG/Element/view)\nSynonyms:\nredraw/dom/svg.view\nredraw/dom/svg view","url":"redraw/dom/svg.html#view"},{"doc":"redraw/dom/svg","title":"redraw/dom/svg","content":" All built-in browser components, such as `&lt;svg&gt;`, `&lt;g&gt;`, etc. support\n common props and events. \\\n To stay compatible with the Lustre API, Redraw defines the entire set of\n SVG elements. They&#39;re instantiated with JSX under-the-hood, and requires\n a modern runtime to get them working.\n\n [Find detailed documentation on MDN](https://developer.mozilla.org/docs/Web/SVG/Element).","url":"redraw/dom/svg.html"}]);